shithub: pokecrystal

Download patch

ref: 80480821142d7a7b16dd2b1a98a213e7b389af0f
parent: 2b823389208c7c3691109ad751ccc39aa2408387
author: Remy Oukaour <[email protected]>
date: Tue Jan 16 09:30:10 EST 2018

Remove Predef_ prefix from routines listed in PredefPointers

--- a/data/predef_pointers.asm
+++ b/data/predef_pointers.asm
@@ -7,79 +7,79 @@
 ENDM
 
 PredefPointers:: ; 856b
-	add_predef Predef_LearnMove ; $0
+	add_predef LearnMove ; $0
 	add_predef DummyPredef1
 	add_predef HealParty ; this is both a special and a predef
-	add_predef Predef_SmallFarFlagAction
-	add_predef Predef_ComputeHPBarPixels
-	add_predef Predef_FillPP
-	add_predef Predef_TryAddMonToParty
-	add_predef Predef_AddTempmonToParty
-	add_predef Predef_SendGetPkmnIntoFromBox
-	add_predef Predef_SendPkmnIntoBox
-	add_predef Predef_GiveEgg
-	add_predef Predef_AnimateHPBar
-	add_predef Predef_CalcPkmnStats
-	add_predef Predef_CalcPkmnStatC
-	add_predef Predef_CanLearnTMHMMove
-	add_predef Predef_GetTMHMMove
-	add_predef Predef_LinkTextbox ; $ 10
-	add_predef Predef_PrintMoveDesc
-	add_predef Predef_UpdatePlayerHUD
-	add_predef Predef_PlaceGraphic
-	add_predef Predef_CheckPlayerPartyForFitPkmn
-	add_predef Predef_UpdateEnemyHUD
-	add_predef Predef_StartBattle
-	add_predef Predef_FillInExpBar
-	add_predef Predef_GetBattleMonBackpic ; $18
-	add_predef Predef_GetEnemyMonFrontpic
-	add_predef Predef_LearnLevelMoves
-	add_predef Predef_FillMoves
-	add_predef Predef_EvolveAfterBattle
-	add_predef Predef_TradeAnimationPlayer2
-	add_predef Predef_TradeAnimation
-	add_predef Predef_CopyPkmnToTempMon
-	add_predef Predef_ListMoves ; $20
-	add_predef Predef_PlaceNonFaintStatus
-	add_predef UnusedPredef22
-	add_predef Predef_ListMovePP
-	add_predef Predef_GetGender
-	add_predef Predef_StatsScreenInit
-	add_predef Predef_DrawPlayerHP
-	add_predef Predef_DrawEnemyHP
-	add_predef Predef_PrintTempMonStats ; $28
-	add_predef Predef_GetTypeName
-	add_predef Predef_PrintMoveType
-	add_predef Predef_PrintType
-	add_predef Predef_PrintMonTypes
-	add_predef Predef_GetUnownLetter
-	add_predef Predef_LoadPoisonBGPals
+	add_predef SmallFarFlagAction
+	add_predef ComputeHPBarPixels
+	add_predef FillPP
+	add_predef TryAddMonToParty
+	add_predef AddTempmonToParty
+	add_predef SendGetPkmnIntoFromBox
+	add_predef SendPkmnIntoBox
+	add_predef GiveEgg
+	add_predef AnimateHPBar
+	add_predef CalcPkmnStats
+	add_predef CalcPkmnStatC
+	add_predef CanLearnTMHMMove
+	add_predef GetTMHMMove
+	add_predef LinkTextboxAtHL ; $ 10
+	add_predef PrintMoveDesc
+	add_predef UpdatePlayerHUD
+	add_predef PlaceGraphic
+	add_predef CheckPlayerPartyForFitPkmn
+	add_predef UpdateEnemyHUD
+	add_predef StartBattle
+	add_predef FillInExpBar
+	add_predef GetBattleMonBackpic ; $18
+	add_predef GetEnemyMonFrontpic
+	add_predef LearnLevelMoves
+	add_predef FillMoves
+	add_predef EvolveAfterBattle
+	add_predef TradeAnimationPlayer2
+	add_predef TradeAnimation
+	add_predef CopyPkmnToTempMon
+	add_predef ListMoves ; $20
+	add_predef PlaceNonFaintStatus
+	add_predef Unused_PlaceEnemyHPLevel
+	add_predef ListMovePP
+	add_predef GetGender
+	add_predef StatsScreenInit
+	add_predef DrawPlayerHP
+	add_predef DrawEnemyHP
+	add_predef PrintTempMonStats ; $28
+	add_predef GetTypeName
+	add_predef PrintMoveType
+	add_predef PrintType
+	add_predef PrintMonTypes
+	add_predef GetUnownLetter
+	add_predef LoadPoisonBGPals
 	add_predef DummyPredef2F
-	add_predef Predef_InitSGBBorder ; $30
-	add_predef Predef_LoadSGBLayout
-	add_predef Predef_Pokedex_GetArea
-	add_predef UnusedPredef_CheckContestMon
-	add_predef Predef_DoBattleTransition
+	add_predef InitSGBBorder ; $30
+	add_predef LoadSGBLayout
+	add_predef Pokedex_GetArea
+	add_predef Unused_CheckContestMon
+	add_predef DoBattleTransition
 	add_predef DummyPredef35
 	add_predef DummyPredef36
-	add_predef Predef_PlayBattleAnim
+	add_predef PlayBattleAnim
 	add_predef DummyPredef38 ; $38
 	add_predef DummyPredef39
 	add_predef DummyPredef3A
-	add_predef Predef_PartyMonItemName
-	add_predef Predef_GetMonFrontpic
-	add_predef Predef_GetMonBackpic
-	add_predef Predef_GetAnimatedFrontpic
-	add_predef Predef_GetTrainerPic
-	add_predef Predef_Decompress ; $40
-	add_predef Predef_CheckTypeMatchup
-	add_predef Predef_ConvertMon_1to2
-	add_predef Predef_NewPokedexEntry
-	add_predef UnusedPredef_AnimateMon_Slow_Normal
-	add_predef Predef_PlaceStatusString
-	add_predef Predef_LoadMonAnimation
-	add_predef Predef_AnimateFrontpic
-	add_predef UnusedPredef48 ; $48
-	add_predef Predef_HOF_AnimateFrontpic
+	add_predef PartyMonItemName
+	add_predef GetMonFrontpic
+	add_predef GetMonBackpic
+	add_predef GetAnimatedFrontpic
+	add_predef GetTrainerPic
+	add_predef DecompressGet2bpp ; $40
+	add_predef CheckTypeMatchup
+	add_predef ConvertMon_1to2
+	add_predef NewPokedexEntry
+	add_predef Unused_AnimateMon_Slow_Normal
+	add_predef PlaceStatusString
+	add_predef LoadMonAnimation
+	add_predef AnimateFrontpic
+	add_predef Unused_HOF_AnimateAlignedFrontpic ; $48
+	add_predef HOF_AnimateFrontpic
 	dbw -1, InexplicablyEmptyFunction ; ???
 ; 864c
--- a/engine/battle/ai/items.asm
+++ b/engine/battle/ai/items.asm
@@ -545,7 +545,7 @@
 
 AIUpdateHUD: ; 38387
 	call UpdateEnemyMonInParty
-	farcall Predef_UpdateEnemyHUD
+	farcall UpdateEnemyHUD
 	ld a, $1
 	ld [hBGMapMode], a
 	ld hl, wEnemyItemState
@@ -664,7 +664,7 @@
 	xor a
 	ld [wWhichHPBar], a
 	call AIUsedItemSound
-	predef Predef_AnimateHPBar
+	predef AnimateHPBar
 	jp AIUpdateHUD
 
 
--- a/engine/battle/ai/move.asm
+++ b/engine/battle/ai/move.asm
@@ -92,7 +92,7 @@
 
 	push bc
 	ld d, BANK(TrainerClassAttributes)
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	ld d, c
 	pop bc
 
--- a/engine/battle/ai/scoring.asm
+++ b/engine/battle/ai/scoring.asm
@@ -1488,7 +1488,7 @@
 	push hl
 	ld a, [wEnemyMoveStruct + MOVE_TYPE]
 	ld hl, EnemyMonType1
-	predef Predef_CheckTypeMatchup
+	predef CheckTypeMatchup
 
 	pop hl
 	ld a, [wd265]
--- a/engine/battle/ai/switch.asm
+++ b/engine/battle/ai/switch.asm
@@ -28,7 +28,7 @@
 	inc hl
 	call GetMoveByte
 	ld hl, EnemyMonType
-	call Predef_CheckTypeMatchup
+	call CheckTypeMatchup
 	ld a, [wTypeMatchup]
 	cp 10 + 1 ; 1.0 + 0.1
 	jr nc, .super_effective
@@ -73,7 +73,7 @@
 	ld a, [BattleMonType1]
 	ld b, a
 	ld hl, EnemyMonType1
-	call Predef_CheckTypeMatchup
+	call CheckTypeMatchup
 	ld a, [wTypeMatchup]
 	cp 10 + 1 ; 1.0 + 0.1
 	jr c, .ok
@@ -82,7 +82,7 @@
 	ld a, [BattleMonType2]
 	cp b
 	jr z, .ok2
-	call Predef_CheckTypeMatchup
+	call CheckTypeMatchup
 	ld a, [wTypeMatchup]
 	cp 10 + 1 ; 1.0 + 0.1
 	jr c, .ok2
@@ -123,7 +123,7 @@
 	inc hl
 	call GetMoveByte
 	ld hl, BattleMonType1
-	call Predef_CheckTypeMatchup
+	call CheckTypeMatchup
 
 	ld a, [wTypeMatchup]
 	; immune
@@ -390,7 +390,7 @@
 	inc hl
 	call GetMoveByte
 	ld hl, BaseType
-	call Predef_CheckTypeMatchup
+	call CheckTypeMatchup
 	ld a, [wTypeMatchup]
 	and a
 	jr nz, .next
@@ -481,7 +481,7 @@
 	inc hl
 	call GetMoveByte
 	ld hl, BattleMonType1
-	call Predef_CheckTypeMatchup
+	call CheckTypeMatchup
 
 	; if immune or not very effective: continue
 	ld a, [wTypeMatchup]
@@ -585,7 +585,7 @@
 .skip_move
 	ld a, [BattleMonType1]
 	ld hl, BaseType
-	call Predef_CheckTypeMatchup
+	call CheckTypeMatchup
 	ld a, [wTypeMatchup]
 	cp 10 + 1
 	jr nc, .dont_choose_mon
@@ -593,7 +593,7 @@
 
 .check_type
 	ld hl, BaseType
-	call Predef_CheckTypeMatchup
+	call CheckTypeMatchup
 	ld a, [wTypeMatchup]
 	cp 10 + 1
 	jr nc, .dont_choose_mon
--- a/engine/battle/battle_transition.asm
+++ b/engine/battle/battle_transition.asm
@@ -1,4 +1,4 @@
-Predef_DoBattleTransition: ; 8c20f
+DoBattleTransition: ; 8c20f
 	call .InitGFX
 	ld a, [rBGP]
 	ld [wBGP], a
--- a/engine/battle/core.asm
+++ b/engine/battle/core.asm
@@ -47,7 +47,7 @@
 
 .player_2
 	call LoadTileMapToTempTileMap
-	call Predef_CheckPlayerPartyForFitPkmn
+	call CheckPlayerPartyForFitPkmn
 	ld a, d
 	and a
 	jp z, LostBattle
@@ -1278,7 +1278,7 @@
 	xor a
 	ld [wNumHits], a
 	ld [FXAnimID + 1], a
-	predef Predef_PlayBattleAnim
+	predef PlayBattleAnim
 	call SwitchTurnCore
 
 .skip_anim
@@ -2040,7 +2040,7 @@
 .ok
 	push bc
 	ld [wWhichHPBar], a
-	predef Predef_AnimateHPBar
+	predef AnimateHPBar
 	pop bc
 	ret
 ; 3cd55
@@ -2054,7 +2054,7 @@
 	xor a
 	ld [wWhichMonFaintedFirst], a
 	call UpdateBattleStateAndExperienceAfterEnemyFaint
-	call Predef_CheckPlayerPartyForFitPkmn
+	call CheckPlayerPartyForFitPkmn
 	ld a, d
 	and a
 	jp z, LostBattle
@@ -2062,7 +2062,7 @@
 	ld hl, BattleMonHP
 	ld a, [hli]
 	or [hl]
-	call nz, Predef_UpdatePlayerHUD
+	call nz, UpdatePlayerHUD
 
 	ld a, $1
 	ld [hBGMapMode], a
@@ -2186,7 +2186,7 @@
 	call PlayerMonFaintHappinessMod
 
 .player_mon_did_not_faint
-	call Predef_CheckPlayerPartyForFitPkmn
+	call CheckPlayerPartyForFitPkmn
 	ld a, d
 	and a
 	ret z
@@ -2670,7 +2670,7 @@
 	ld a, $1
 	ld [wWhichMonFaintedFirst], a
 	call PlayerMonFaintHappinessMod
-	call Predef_CheckPlayerPartyForFitPkmn
+	call CheckPlayerPartyForFitPkmn
 	ld a, d
 	and a
 	jp z, LostBattle
@@ -2716,7 +2716,7 @@
 	ld c, a
 	ld hl, wBattleParticipantsNotFainted
 	ld b, RESET_FLAG
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	ld hl, EnemySubStatus3
 	res SUBSTATUS_IN_LOOP, [hl]
 	xor a
@@ -3313,10 +3313,10 @@
 	ld hl, wBattleParticipantsNotFainted
 	ld b, SET_FLAG
 	push bc
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	pop bc
 	ld hl, wBattleParticipantsIncludingFainted
-	predef_jump Predef_SmallFarFlagAction
+	predef_jump SmallFarFlagAction
 ; 3d599
 
 FindPkmnInOTPartyToSwitchIntoBattle: ; 3d599
@@ -3534,7 +3534,7 @@
 	and a
 	jr nz, .skip_unown
 	ld hl, EnemyMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	ld a, [UnownLetter]
 	ld [wFirstUnownSeen], a
 .skip_unown
@@ -3644,8 +3644,8 @@
 	call GetBaseData
 	ld a, OTPARTYMON
 	ld [MonType], a
-	predef Predef_CopyPkmnToTempMon
-	call Predef_GetEnemyMonFrontpic
+	predef CopyPkmnToTempMon
+	call GetEnemyMonFrontpic
 
 	xor a
 	ld [wNumHits], a
@@ -3670,7 +3670,7 @@
 	hlcoord 12, 0
 	ld d, $0
 	ld e, ANIM_MON_SLOW
-	predef Predef_AnimateFrontpic
+	predef AnimateFrontpic
 	jr .skip_cry
 
 .cry_no_anim
@@ -3680,7 +3680,7 @@
 	call PlayStereoCry
 
 .skip_cry
-	call Predef_UpdateEnemyHUD
+	call UpdateEnemyHUD
 	ld a, $1
 	ld [hBGMapMode], a
 	ret
@@ -3721,7 +3721,7 @@
 	ret
 ; 3d873
 
-Predef_CheckPlayerPartyForFitPkmn: ; 3d873
+CheckPlayerPartyForFitPkmn: ; 3d873
 ; Has the player any Pkmn in his Party that can fight?
 	ld a, [PartyCount]
 	ld e, a
@@ -4124,7 +4124,7 @@
 
 SendOutPlayerMon: ; 3db5f
 	ld hl, BattleMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	hlcoord 1, 5
 	ld b, 7
 	ld c, 8
@@ -4132,7 +4132,7 @@
 	call WaitBGMap
 	xor a
 	ld [hBGMapMode], a
-	call Predef_GetBattleMonBackpic
+	call GetBattleMonBackpic
 	xor a
 	ld [hGraphicStartTile], a
 	ld [wBattleMenuCursorBuffer], a
@@ -4172,7 +4172,7 @@
 	call PlayStereoCry
 
 .statused
-	call Predef_UpdatePlayerHUD
+	call UpdatePlayerHUD
 	ld a, $1
 	ld [hBGMapMode], a
 	ret
@@ -4218,13 +4218,13 @@
 SpikesDamage: ; 3dc23
 	ld hl, PlayerScreens
 	ld de, BattleMonType
-	ld bc, Predef_UpdatePlayerHUD
+	ld bc, UpdatePlayerHUD
 	ld a, [hBattleTurn]
 	and a
 	jr z, .ok
 	ld hl, EnemyScreens
 	ld de, EnemyMonType
-	ld bc, Predef_UpdateEnemyHUD
+	ld bc, UpdateEnemyHUD
 .ok
 
 	bit SCREENS_SPIKES, [hl]
@@ -4306,7 +4306,7 @@
 	ld c, a
 	ld hl, wBattleParticipantsNotFainted
 	ld b, RESET_FLAG
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	call PlayerMonFaintedAnimation
 	ld hl, BattleText_PkmnFainted
 	jr .done_fainted
@@ -4455,7 +4455,7 @@
 
 .got_hp_bar_coords
 	ld [wWhichHPBar], a
-	predef Predef_AnimateHPBar
+	predef AnimateHPBar
 UseOpponentItem:
 	call RefreshBattleHuds
 	callfar GetOpponentItem
@@ -4478,7 +4478,7 @@
 	xor a
 	ld [wNumHits], a
 	ld [FXAnimID + 1], a
-	predef Predef_PlayBattleAnim
+	predef PlayBattleAnim
 	call SwitchTurnCore
 	pop bc
 	pop de
@@ -4708,7 +4708,7 @@
 	ret
 ; 3df48
 
-Predef_UpdatePlayerHUD:: ; 3df48
+UpdatePlayerHUD:: ; 3df48
 	push hl
 	push de
 	push bc
@@ -4741,7 +4741,7 @@
 	ld b, 1
 	xor a ; PARTYMON
 	ld [MonType], a
-	predef Predef_DrawPlayerHP
+	predef DrawPlayerHP
 
 	; Exp bar
 	push de
@@ -4754,7 +4754,7 @@
 	hlcoord 10, 11
 	ld a, [TempMonLevel]
 	ld b, a
-	call Predef_FillInExpBar
+	call FillInExpBar
 	pop de
 	ret
 ; 3df98
@@ -4823,7 +4823,7 @@
 
 	ld a, TEMPMON
 	ld [MonType], a
-	callfar Predef_GetGender
+	callfar GetGender
 	ld a, " "
 	jr c, .got_gender_char
 	ld a, "♂"
@@ -4837,7 +4837,7 @@
 	push af ; back up gender
 	push hl
 	ld de, BattleMonStatus
-	predef Predef_PlaceNonFaintStatus
+	predef PlaceNonFaintStatus
 	pop hl
 	pop bc
 	ret nz
@@ -4852,7 +4852,7 @@
 	jp PrintLevel
 ; 3e036
 
-Predef_UpdateEnemyHUD:: ; 3e036
+UpdateEnemyHUD:: ; 3e036
 	push hl
 	push de
 	push bc
@@ -4901,7 +4901,7 @@
 
 	ld a, TEMPMON
 	ld [MonType], a
-	callfar Predef_GetGender
+	callfar GetGender
 	ld a, " "
 	jr c, .got_gender
 	ld a, "♂"
@@ -4916,7 +4916,7 @@
 	push af
 	push hl
 	ld de, EnemyMonStatus
-	predef Predef_PlaceNonFaintStatus
+	predef PlaceNonFaintStatus
 	pop hl
 	pop bc
 	jr nz, .skip_level
@@ -5141,8 +5141,8 @@
 	call ClearPalettes
 	call DelayFrame
 	call _LoadBattleFontsHPBar
-	call Predef_GetBattleMonBackpic
-	call Predef_GetEnemyMonFrontpic
+	call GetBattleMonBackpic
+	call GetEnemyMonFrontpic
 	call ExitMenu
 	call WaitBGMap
 	call FinishBattleAnim
@@ -5174,10 +5174,10 @@
 	ld a, [BattleType]
 	cp BATTLETYPE_TUTORIAL
 	jr z, .tutorial2
-	call Predef_GetBattleMonBackpic
+	call GetBattleMonBackpic
 
 .tutorial2
-	call Predef_GetEnemyMonFrontpic
+	call GetEnemyMonFrontpic
 	ld a, $1
 	ld [wMenuCursorY], a
 	call ExitMenu
@@ -5531,7 +5531,7 @@
 .got_start_coord
 	ld a, SCREEN_WIDTH
 	ld [Buffer1], a
-	predef Predef_ListMoves
+	predef ListMoves
 
 	ld b, 5
 	ld a, [wMoveSelectionMenuType]
@@ -5864,7 +5864,7 @@
 	ld a, [wPlayerMoveStruct + MOVE_ANIM]
 	ld b, a
 	hlcoord 2, 10
-	predef Predef_PrintMoveType
+	predef PrintMoveType
 
 .done
 	ret
@@ -6319,7 +6319,7 @@
 
 ; Get letter based on DVs
 	ld hl, EnemyMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 ; Can't use any letters that haven't been unlocked
 ; If combined with forced shiny battletype, causes an infinite loop
 	call CheckUnownLetter
@@ -6408,7 +6408,7 @@
 	ld de, EnemyMonMaxHP
 	ld b, FALSE
 	ld hl, EnemyMonDVs - (MON_DVS - MON_STAT_EXP + 1) ; LinkBattleRNs + 7 ; ?
-	predef Predef_CalcPkmnStats
+	predef CalcPkmnStats
 
 ; If we're in a trainer battle,
 ; get the rest of the parameters from the party struct
@@ -6523,7 +6523,7 @@
 ; Make sure the predef knows this isn't a partymon
 	ld [wEvolutionOldSpecies], a
 ; Fill moves based on level
-	predef Predef_FillMoves
+	predef FillMoves
 
 .PP:
 ; Trainer battle?
@@ -6534,7 +6534,7 @@
 ; Fill wild PP
 	ld hl, EnemyMonMoves
 	ld de, EnemyMonPP
-	predef Predef_FillPP
+	predef FillPP
 	jr .Finish
 
 .TrainerPP:
@@ -6587,7 +6587,7 @@
 	ld c, a
 	ld b, SET_FLAG
 	ld hl, PokedexSeen
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 
 	ld hl, EnemyMonStats
 	ld de, EnemyStats
@@ -6715,7 +6715,7 @@
 	ld a, [OtherTrainerClass]
 	ld [TrainerClass], a
 	ld de, vTiles2
-	callfar Predef_GetTrainerPic
+	callfar GetTrainerPic
 	hlcoord 19, 0
 	ld c, 0
 
@@ -7192,7 +7192,7 @@
 	ld a, d
 	ld [FXAnimID + 1], a
 	call WaitBGMap
-	predef_jump Predef_PlayBattleAnim
+	predef_jump PlayBattleAnim
 ; 3ee27
 
 FinishBattleAnim: ; 3ee27
@@ -7240,7 +7240,7 @@
 	ld c, a
 	ld b, CHECK_FLAG
 	ld d, $0
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	ld a, c
 	and a
 	pop bc
@@ -7418,7 +7418,7 @@
 .not_max_exp
 	xor a ; PARTYMON
 	ld [MonType], a
-	predef Predef_CopyPkmnToTempMon
+	predef CopyPkmnToTempMon
 	callfar CalcLevel
 	pop bc
 	ld hl, MON_LEVEL
@@ -7455,7 +7455,7 @@
 	add hl, bc
 	push bc
 	ld b, TRUE
-	predef Predef_CalcPkmnStats
+	predef CalcPkmnStats
 	pop bc
 	pop de
 	ld hl, MON_MAXHP + 1
@@ -7508,7 +7508,7 @@
 	call ApplyStatLevelMultiplierOnAllStats
 	callfar ApplyStatusEffectOnPlayerStats
 	callfar BadgeStatBoosts
-	callfar Predef_UpdatePlayerHUD
+	callfar UpdatePlayerHUD
 	call EmptyBattleTextBox
 	call LoadTileMapToTempTileMap
 	ld a, $1
@@ -7531,7 +7531,7 @@
 .skip_animation2
 	xor a ; PARTYMON
 	ld [MonType], a
-	predef Predef_CopyPkmnToTempMon
+	predef CopyPkmnToTempMon
 	hlcoord 9, 0
 	ld b, $a
 	ld c, $9
@@ -7538,7 +7538,7 @@
 	call TextBox
 	hlcoord 11, 1
 	ld bc, 4
-	predef Predef_PrintTempMonStats
+	predef PrintTempMonStats
 	ld c, $1e
 	call DelayFrames
 	call WaitPressAorB_BlinkCursor
@@ -7558,7 +7558,7 @@
 	ld a, b
 	ld [CurPartyLevel], a
 	push bc
-	predef Predef_LearnLevelMoves
+	predef LearnLevelMoves
 	pop bc
 	ld a, b
 	cp c
@@ -7569,7 +7569,7 @@
 	ld a, [CurPartyMon]
 	ld c, a
 	ld b, SET_FLAG
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	pop af
 	ld [CurPartyLevel], a
 
@@ -7691,7 +7691,7 @@
 	ld [wd002], a
 	xor a ; PARTYMON
 	ld [MonType], a
-	predef Predef_CopyPkmnToTempMon
+	predef CopyPkmnToTempMon
 	ld a, [TempMonLevel]
 	ld b, a
 	ld e, a
@@ -8062,7 +8062,7 @@
 	jp StdBattleTextBox
 ; 3f390
 
-Predef_FillInExpBar: ; 3f390
+FillInExpBar: ; 3f390
 	push hl
 	call CalcExpBar
 	pop hl
@@ -8204,7 +8204,7 @@
 	ret
 ; 3f43d
 
-Predef_GetBattleMonBackpic: ; 3f43d
+GetBattleMonBackpic: ; 3f43d
 	ld a, [PlayerSubStatus4]
 	bit SUBSTATUS_SUBSTITUTE, a
 	ld hl, BattleAnimCmd_RaiseSub
@@ -8220,9 +8220,9 @@
 	ld a, [BattleMonSpecies]
 	ld [CurPartySpecies], a
 	ld hl, BattleMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	ld de, vTiles2 tile $31
-	predef Predef_GetMonBackpic
+	predef GetMonBackpic
 	pop af
 	ld [CurPartySpecies], a
 	ret
@@ -8240,7 +8240,7 @@
 	ret
 ; 3f47c
 
-Predef_GetEnemyMonFrontpic: ; 3f47c
+GetEnemyMonFrontpic: ; 3f47c
 	ld a, [EnemySubStatus4]
 	bit SUBSTATUS_SUBSTITUTE, a
 	ld hl, BattleAnimCmd_RaiseSub
@@ -8259,9 +8259,9 @@
 	ld [CurPartySpecies], a
 	call GetBaseData
 	ld hl, EnemyMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	ld de, vTiles2
-	predef Predef_GetAnimatedFrontpic
+	predef GetAnimatedFrontpic
 	pop af
 	ld [CurPartySpecies], a
 	ret
@@ -8278,7 +8278,7 @@
 	ret
 ; 3f4c1
 
-Predef_StartBattle: ; 3f4c1
+StartBattle: ; 3f4c1
 ; This check prevents you from entering a battle without any Pokemon.
 ; Those using walk-through-walls to bypass getting a Pokemon experience
 ; the effects of this check.
@@ -8337,7 +8337,7 @@
 	call ClearSprites
 	ld a, [wBattleMode]
 	cp WILD_BATTLE
-	call z, Predef_UpdateEnemyHUD
+	call z, UpdateEnemyHUD
 	ld a, $1
 	ld [hBGMapMode], a
 	ret
@@ -8402,7 +8402,7 @@
 .ok
 
 	ld de, vTiles2
-	callfar Predef_GetTrainerPic
+	callfar GetTrainerPic
 	xor a
 	ld [hGraphicStartTile], a
 	dec a
@@ -8409,7 +8409,7 @@
 	ld [wEnemyItemState], a
 	hlcoord 12, 0
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ld a, -1
 	ld [CurOTMon], a
 	ld a, TRAINER_BATTLE
@@ -8455,7 +8455,7 @@
 	ld bc, NUM_MOVES
 	call CopyBytes
 	ld hl, EnemyMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	ld a, [CurPartySpecies]
 	cp UNOWN
 	jr nz, .skip_unown
@@ -8466,13 +8466,13 @@
 	ld [wFirstUnownSeen], a
 .skip_unown
 	ld de, vTiles2
-	predef Predef_GetAnimatedFrontpic
+	predef GetAnimatedFrontpic
 	xor a
 	ld [TrainerClass], a
 	ld [hGraphicStartTile], a
 	hlcoord 12, 0
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ret
 ; 3f662
 
@@ -8551,7 +8551,7 @@
 	call CheckPayDay
 	xor a
 	ld [wForceEvolution], a
-	predef Predef_EvolveAfterBattle
+	predef EvolveAfterBattle
 	farcall GivePokerusAndConvertBerries
 	ret
 ; 3f6d0
@@ -9225,7 +9225,7 @@
 	ld [hGraphicStartTile], a
 	hlcoord 2, 6
 	lb bc, 6, 6
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	xor a
 	ld [hWY], a
 	ld [rWY], a
@@ -9297,8 +9297,8 @@
 
 .Decompress:
 	ld de, vTiles2 tile $31
-	ld c, $31
-	predef Predef_Decompress
+	ld c, 7 * 7
+	predef DecompressGet2bpp
 	ret
 ; 3fc30
 
@@ -9320,7 +9320,7 @@
 	ld [hGraphicStartTile], a
 	hlcoord 2, 6
 	lb bc, 6, 6
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ret
 ; 3fc5b
 
@@ -9400,7 +9400,7 @@
 	hlcoord 12, 0
 	ld d, $0
 	ld e, ANIM_MON_NORMAL
-	predef Predef_AnimateFrontpic
+	predef AnimateFrontpic
 	jr .skip_cry ; cry is played during the animation
 
 .cry_no_anim
--- a/engine/battle/effect_commands/attract.asm
+++ b/engine/battle/effect_commands/attract.asm
@@ -35,7 +35,7 @@
 	xor a
 	ld [MonType], a
 
-	farcall Predef_GetGender
+	farcall GetGender
 	jr c, .genderless_samegender
 
 	ld b, 1
@@ -58,7 +58,7 @@
 	ld [TempMonDVs + 1], a
 	ld a, 3
 	ld [MonType], a
-	farcall Predef_GetGender
+	farcall GetGender
 	pop bc
 	jr c, .genderless_samegender
 
--- a/engine/battle/misc.asm
+++ b/engine/battle/misc.asm
@@ -33,7 +33,7 @@
 	ld a, $31
 .okay
 	ld [hGraphicStartTile], a
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 FinishAppearDisappearUser: ; fbd91 (3e:7d91)
 	ld a, $1
 	ld [hBGMapMode], a
--- a/engine/battle/read_trainer_party.asm
+++ b/engine/battle/read_trainer_party.asm
@@ -103,7 +103,7 @@
 	ld a, OTPARTYMON
 	ld [MonType], a
 	push hl
-	predef Predef_TryAddMonToParty
+	predef TryAddMonToParty
 	pop hl
 	jr .loop
 ; 39806
@@ -124,7 +124,7 @@
 	ld [MonType], a
 
 	push hl
-	predef Predef_TryAddMonToParty
+	predef TryAddMonToParty
 	ld a, [OTPartyCount]
 	dec a
 	ld hl, OTPartyMon1Moves
@@ -200,7 +200,7 @@
 	ld a, OTPARTYMON
 	ld [MonType], a
 	push hl
-	predef Predef_TryAddMonToParty
+	predef TryAddMonToParty
 	ld a, [OTPartyCount]
 	dec a
 	ld hl, OTPartyMon1Item
@@ -231,7 +231,7 @@
 	ld [MonType], a
 
 	push hl
-	predef Predef_TryAddMonToParty
+	predef TryAddMonToParty
 	ld a, [OTPartyCount]
 	dec a
 	ld hl, OTPartyMon1Item
--- a/engine/battle/returntobattle_useball.asm
+++ b/engine/battle/returntobattle_useball.asm
@@ -4,13 +4,13 @@
 	ld a, [BattleType]
 	cp BATTLETYPE_TUTORIAL
 	jr z, .gettutorialbackpic
-	farcall Predef_GetBattleMonBackpic
+	farcall GetBattleMonBackpic
 	jr .continue
 
 .gettutorialbackpic
 	farcall GetTrainerBackpic
 .continue
-	farcall Predef_GetEnemyMonFrontpic
+	farcall GetEnemyMonFrontpic
 	farcall _LoadBattleFontsHPBar
 	call GetMemSGBLayout
 	call CloseWindow
--- a/engine/battle/start_battle.asm
+++ b/engine/battle/start_battle.asm
@@ -33,7 +33,7 @@
 	add hl, de
 	ld a, [hl]
 	ld [BattleMonLevel], a
-	predef Predef_DoBattleTransition
+	predef DoBattleTransition
 	farcall _LoadBattleFontsHPBar
 	ld a, 1
 	ld [hBGMapMode], a
--- a/engine/battle_anims/anim_commands.asm
+++ b/engine/battle_anims/anim_commands.asm
@@ -1,6 +1,6 @@
 ; Battle animation command interpreter.
 
-Predef_PlayBattleAnim: ; cc0d6
+PlayBattleAnim: ; cc0d6
 
 	ld a, [rSVBK]
 	push af
@@ -167,7 +167,7 @@
 	ld [rSVBK], a
 
 	ld hl, UpdateBattleHuds
-	ld a, BANK(Predef_UpdatePlayerHUD)
+	ld a, BANK(UpdatePlayerHUD)
 	rst FarCall ; Why not "call UpdateBattleHuds"?
 
 	pop af
@@ -928,9 +928,9 @@
 	ld a, [TempBattleMonSpecies] ; TempBattleMonSpecies
 	ld [CurPartySpecies], a ; CurPartySpecies
 	ld hl, BattleMonDVs ; BattleMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	ld de, vTiles0 tile $00
-	predef Predef_GetMonFrontpic
+	predef GetMonFrontpic
 	jr .done
 
 .player
@@ -937,9 +937,9 @@
 	ld a, [TempEnemyMonSpecies] ; TempEnemyMonSpecies
 	ld [CurPartySpecies], a ; CurPartySpecies
 	ld hl, EnemyMonDVs ; EnemyMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	ld de, vTiles0 tile $00
-	predef Predef_GetMonBackpic
+	predef GetMonBackpic
 
 .done
 	pop af
@@ -1155,16 +1155,16 @@
 	jr z, .player
 
 	ld hl, BattleMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	ld de, vTiles2 tile $00
-	predef Predef_GetMonFrontpic
+	predef GetMonFrontpic
 	jr .done
 
 .player
 	ld hl, EnemyMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	ld de, vTiles2 tile $31
-	predef Predef_GetMonBackpic
+	predef GetMonBackpic
 
 .done
 	pop af
--- a/engine/billspc.asm
+++ b/engine/billspc.asm
@@ -1095,10 +1095,10 @@
 	ld [CurPartySpecies], a
 	ld [CurSpecies], a
 	ld hl, TempMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	call GetBaseData
 	ld de, vTiles2 tile $00
-	predef Predef_GetMonFrontpic
+	predef GetMonFrontpic
 	xor a
 	ld [wBillsPC_MonHasMail], a
 	ld a, [CurPartySpecies]
@@ -1115,7 +1115,7 @@
 
 	ld a, $3
 	ld [MonType], a
-	farcall Predef_GetGender
+	farcall GetGender
 	jr c, .skip_gender
 	ld a, "♂"
 	jr nz, .printgender
@@ -1698,7 +1698,7 @@
 	call BillsPC_CopyMon
 	ld a, $3
 	ld [MonType], a
-	predef Predef_StatsScreenInit
+	predef StatsScreenInit
 	call BillsPC_InitGFX
 	call MaxVolume
 	ret
@@ -1726,7 +1726,7 @@
 	ld [CurPartySpecies], a
 	ld [CurSpecies], a
 	ld hl, TempMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	call GetBaseData
 	call BillsPC_CopyMon
 .pressed_a_b_right_left
@@ -1819,7 +1819,7 @@
 	call GetNick
 	ld a, PC_DEPOSIT
 	ld [wPokemonWithdrawDepositParameter], a
-	predef Predef_SendGetPkmnIntoFromBox
+	predef SendGetPkmnIntoFromBox
 	jr c, .asm_boxisfull
 	xor a
 	ld [wPokemonWithdrawDepositParameter], a
@@ -1874,7 +1874,7 @@
 	call CloseSRAM
 	xor a
 	ld [wPokemonWithdrawDepositParameter], a
-	predef Predef_SendGetPkmnIntoFromBox
+	predef SendGetPkmnIntoFromBox
 	jr c, .PartyFull
 	ld a, PC_DEPOSIT
 	ld [wPokemonWithdrawDepositParameter], a
--- a/engine/breeding.asm
+++ b/engine/breeding.asm
@@ -10,7 +10,7 @@
 	ld [TempMonDVs + 1], a
 	ld a, TEMPMON
 	ld [MonType], a
-	predef Predef_GetGender
+	predef GetGender
 	jr c, .genderless
 	ld b, $1
 	jr nz, .breedmon2
@@ -26,7 +26,7 @@
 	ld [TempMonDVs + 1], a
 	ld a, $3
 	ld [MonType], a
-	predef Predef_GetGender
+	predef GetGender
 	pop bc
 	jr c, .genderless
 	ld a, $1
@@ -289,7 +289,7 @@
 	ld bc, MON_STAT_EXP - 1
 	add hl, bc
 	ld b, $0
-	predef Predef_CalcPkmnStats
+	predef CalcPkmnStats
 	pop bc
 	ld hl, MON_MAXHP
 	add hl, bc
@@ -514,7 +514,7 @@
 	cp b
 	jr nz, .loop5
 	ld [wPutativeTMHMMove], a
-	predef Predef_CanLearnTMHMMove
+	predef CanLearnTMHMMove
 	ld a, c
 	and a
 	jr z, .done
@@ -559,7 +559,7 @@
 	ld [hl], b
 	ld hl, wEggMonMoves
 	ld de, wEggMonPP
-	predef Predef_FillPP
+	predef FillPP
 	pop bc
 	pop de
 	ret
@@ -590,7 +590,7 @@
 	ld [TempMonDVs + 1], a
 	ld a, TEMPMON
 	ld [MonType], a
-	predef Predef_GetGender
+	predef GetGender
 	jr c, .inherit_mon2_moves
 	jr nz, .inherit_mon2_moves
 	jr .inherit_mon1_moves
@@ -606,7 +606,7 @@
 	ld [TempMonDVs + 1], a
 	ld a, TEMPMON
 	ld [MonType], a
-	predef Predef_GetGender
+	predef GetGender
 	jr c, .inherit_mon1_moves
 	jr nz, .inherit_mon1_moves
 
@@ -647,9 +647,9 @@
 	ld [CurSpecies], a
 	call GetBaseData
 	ld hl, BattleMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	pop de
-	predef_jump Predef_GetMonFrontpic
+	predef_jump GetMonFrontpic
 
 GetHatchlingFrontpic: ; 1723c (5:723c)
 	push de
@@ -657,9 +657,9 @@
 	ld [CurSpecies], a
 	call GetBaseData
 	ld hl, BattleMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	pop de
-	predef_jump Predef_GetAnimatedFrontpic
+	predef_jump GetAnimatedFrontpic
 
 Hatch_UpdateFrontpicBGMapCenter: ; 17254 (5:7254)
 	push af
@@ -677,7 +677,7 @@
 	ld a, c
 	ld [hGraphicStartTile], a
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	pop af
 	call Hatch_LoadFrontpicPal
 	call SetPalettes
@@ -779,7 +779,7 @@
 	hlcoord 6, 3
 	ld d, $0
 	ld e, ANIM_MON_HATCH
-	predef Predef_AnimateFrontpic
+	predef AnimateFrontpic
 	pop af
 	ld [CurSpecies], a
 	ret
--- a/engine/color.asm
+++ b/engine/color.asm
@@ -43,7 +43,7 @@
 	and a
 	ret
 
-UnusedPredef_CheckContestMon:
+Unused_CheckContestMon:
 ; Check a mon's DVs at hl in the bug catching contest.
 ; Return carry if its DVs are good enough to place in the contest.
 
@@ -855,7 +855,7 @@
 	jr nz, .loop
 	ret
 
-Predef_InitSGBBorder:
+InitSGBBorder:
 	call CheckCGB
 	ret nz
 ; SGB/DMG only
--- a/engine/debug.asm
+++ b/engine/debug.asm
@@ -315,12 +315,12 @@
 	hlcoord 12, 3
 	call _PrepMonFrontpic
 	ld de, vTiles2 tile $31
-	predef Predef_GetMonBackpic
+	predef GetMonBackpic
 	ld a, $31
 	ld [hGraphicStartTile], a
 	hlcoord 2, 4
 	lb bc, 6, 6
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ld a, [wd003]
 	and a
 	jr z, .asm_81b66
@@ -346,13 +346,13 @@
 	hlcoord 4, 1
 	call PlaceString
 	ld de, vTiles2
-	callfar Predef_GetTrainerPic
+	callfar GetTrainerPic
 	xor a
 	ld [TempEnemyMonSpecies], a
 	ld [hGraphicStartTile], a
 	hlcoord 2, 3
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 
 .asm_81ba9
 	ld a, $1
@@ -739,7 +739,7 @@
 	ld a, [wd004]
 	inc a
 	ld [wd265], a
-	predef Predef_GetTMHMMove
+	predef GetTMHMMove
 	ld a, [wd265]
 	ld [wPutativeTMHMMove], a
 	call GetMoveName
@@ -748,7 +748,7 @@
 	ld a, [wd004]
 	call Function81e55
 	ld [CurItem], a
-	predef Predef_CanLearnTMHMMove
+	predef CanLearnTMHMMove
 	ld a, c
 	and a
 	ld de, String_81e46
--- a/engine/events/battle_tower/battle_tower.asm
+++ b/engine/events/battle_tower/battle_tower.asm
@@ -248,7 +248,7 @@
 	call ReadBTTrainerParty
 	call Clears5_a89a
 
-	predef Predef_StartBattle
+	predef StartBattle
 
 	farcall LoadPokemonData
 	farcall HealParty
@@ -484,7 +484,7 @@
 	ld hl, MON_STAT_EXP - 1
 	add hl, bc
 	ld b, $1
-	predef Predef_CalcPkmnStats
+	predef CalcPkmnStats
 	pop de
 	pop hl
 	dec de
--- a/engine/events/catch_tutorial.asm
+++ b/engine/events/catch_tutorial.asm
@@ -41,7 +41,7 @@
 	ld hl, .AutoInput
 	ld a, BANK(.AutoInput)
 	call StartAutoInput
-	callfar Predef_StartBattle
+	callfar StartBattle
 	call StopAutoInput
 	pop af
 
--- a/engine/events/daycare.asm
+++ b/engine/events/daycare.asm
@@ -565,7 +565,7 @@
 	pop hl
 	push bc
 	ld b, $0
-	predef Predef_CalcPkmnStats
+	predef CalcPkmnStats
 	pop bc
 	ld hl, MON_HP
 	add hl, bc
@@ -639,7 +639,7 @@
 	cp DITTO
 	ld a, $0
 	jr z, .LoadWhichBreedmonIsTheMother
-	farcall Predef_GetGender
+	farcall GetGender
 	ld a, $0
 	jr z, .LoadWhichBreedmonIsTheMother
 	inc a
@@ -684,7 +684,7 @@
 	ld de, wEggMonMoves
 	xor a
 	ld [Buffer1], a
-	predef Predef_FillMoves
+	predef FillMoves
 	farcall InitEggMoves
 	ld hl, wEggMonID
 	ld a, [PlayerID]
@@ -726,7 +726,7 @@
 	ld a, TEMPMON
 	ld [MonType], a
 	push hl
-	farcall Predef_GetGender
+	farcall GetGender
 	pop hl
 	ld de, wBreedMon1DVs
 	ld bc, wBreedMon2DVs
@@ -770,7 +770,7 @@
 	call CopyBytes
 	ld hl, wEggMonMoves
 	ld de, wEggMonPP
-	predef Predef_FillPP
+	predef FillPP
 	ld hl, wMonOrItemNameBuffer
 	ld de, StringBuffer1
 	ld bc, NAME_LENGTH
--- a/engine/events/halloffame.asm
+++ b/engine/events/halloffame.asm
@@ -130,7 +130,7 @@
 	call WaitBGMap
 	decoord 6, 5
 	ld c, $6
-	predef Predef_HOF_AnimateFrontpic
+	predef HOF_AnimateFrontpic
 	ld c, 60
 	call DelayFrames
 	and a
@@ -244,18 +244,18 @@
 	ld a, [hli]
 	ld [TempMonDVs + 1], a
 	ld hl, TempMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	hlcoord 0, 0
 	ld bc, SCREEN_WIDTH * SCREEN_HEIGHT
 	ld a, " "
 	call ByteFill
 	ld de, vTiles2 tile $31
-	predef Predef_GetMonBackpic
+	predef GetMonBackpic
 	ld a, $31
 	ld [hGraphicStartTile], a
 	hlcoord 6, 6
 	lb bc, 6, 6
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ld a, $d0
 	ld [hSCY], a
 	ld a, $90
@@ -403,7 +403,7 @@
 	call SetPalettes
 	decoord 6, 5
 	ld c, $6
-	predef Predef_HOF_AnimateFrontpic
+	predef HOF_AnimateFrontpic
 	and a
 	ret
 
@@ -478,7 +478,7 @@
 	ld [CurPartySpecies], a
 	ld [wd265], a
 	ld hl, TempMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	xor a
 	ld [wBoxAlignment], a
 	hlcoord 6, 5
@@ -499,7 +499,7 @@
 	call PlaceString
 	ld a, TEMPMON
 	ld [MonType], a
-	farcall Predef_GetGender
+	farcall GetGender
 	ld a, " "
 	jr c, .got_gender
 	ld a, "♂"
@@ -546,7 +546,7 @@
 	ld [hGraphicStartTile], a
 	hlcoord 6, 6
 	lb bc, 6, 6
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ld a, $d0
 	ld [hSCY], a
 	ld a, $90
@@ -570,7 +570,7 @@
 	ld [hGraphicStartTile], a
 	hlcoord 12, 5
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ld a, $c0
 	ld [hSCX], a
 	call WaitBGMap
--- a/engine/events/move_tutor.asm
+++ b/engine/events/move_tutor.asm
@@ -55,7 +55,7 @@
 	ld hl, .MenuDataHeader
 	call LoadMenuDataHeader
 
-	predef Predef_CanLearnTMHMMove
+	predef CanLearnTMHMMove
 
 	push bc
 	ld a, [CurPartyMon]
@@ -79,7 +79,7 @@
 	callfar KnowsMove
 	jr c, .didnt_learn
 
-	predef Predef_LearnMove
+	predef LearnMove
 	ld a, b
 	and a
 	jr z, .didnt_learn
--- a/engine/events/poisonstep.asm
+++ b/engine/events/poisonstep.asm
@@ -104,7 +104,7 @@
 	ld de, SFX_POISON
 	call PlaySFX
 	ld b, $2
-	predef Predef_LoadPoisonBGPals
+	predef LoadPoisonBGPals
 	call DelayFrame
 	ret
 ; 50669
@@ -145,7 +145,7 @@
 	ld a, [PartyCount]
 	cp [hl]
 	jr nz, .party_loop
-	predef Predef_CheckPlayerPartyForFitPkmn
+	predef CheckPlayerPartyForFitPkmn
 	ld a, d
 	ld [ScriptVar], a
 	ret
--- a/engine/events/poisonstep_pals.asm
+++ b/engine/events/poisonstep_pals.asm
@@ -1,4 +1,4 @@
-Predef_LoadPoisonBGPals: ; cbcdd
+LoadPoisonBGPals: ; cbcdd
 	call .LoadPals
 	ld a, [hCGB]
 	and a
--- a/engine/events/pokecenter_pc.asm
+++ b/engine/events/pokecenter_pc.asm
@@ -353,7 +353,7 @@
 	ld [CurItemQuantity], a
 	ld hl, PCItems
 	call TossItem
-	predef Predef_PartyMonItemName
+	predef PartyMonItemName
 	ld hl, .WithdrewText
 	call MenuTextBox
 	xor a
@@ -517,7 +517,7 @@
 	ld [CurItemQuantity], a
 	ld hl, NumItems
 	call TossItem
-	predef Predef_PartyMonItemName
+	predef PartyMonItemName
 	ld hl, .DepositText
 	call PrintText
 	ret
--- a/engine/events/pokepic.asm
+++ b/engine/events/pokepic.asm
@@ -12,7 +12,7 @@
 	ld [CurSpecies], a
 	call GetBaseData
 	ld de, vTiles1
-	predef Predef_GetMonFrontpic
+	predef GetMonFrontpic
 	ld a, [wMenuBorderTopCoord]
 	inc a
 	ld b, a
@@ -23,7 +23,7 @@
 	ld a, $80
 	ld [hGraphicStartTile], a
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	call WaitBGMap
 	ret
 
--- a/engine/events/print_unown.asm
+++ b/engine/events/print_unown.asm
@@ -140,13 +140,13 @@
 	xor a
 	ld [wBoxAlignment], a
 	ld de, vTiles2
-	predef Predef_GetMonFrontpic
+	predef GetMonFrontpic
 	call .Load2bppToSRAM
 	hlcoord 1, 6
 	xor a
 	ld [hGraphicStartTile], a
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ld de, vTiles2 tile $31
 	farcall RotateUnownFrontpic
 	ret
@@ -228,6 +228,6 @@
 	ld a, $31
 	ld [hGraphicStartTile], a
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ret
 ; 16dc7
--- a/engine/events/special.asm
+++ b/engine/events/special.asm
@@ -12,7 +12,7 @@
 	ld a, 15
 	ld [CurPartyLevel], a
 
-	predef Predef_TryAddMonToParty
+	predef TryAddMonToParty
 	jr nc, .NotGiven
 
 ; Caught data.
--- a/engine/evolution_animation.asm
+++ b/engine/evolution_animation.asm
@@ -122,7 +122,7 @@
 	hlcoord 7, 2
 	ld d, $0
 	ld e, ANIM_MON_EVOLVE
-	predef Predef_AnimateFrontpic
+	predef AnimateFrontpic
 
 	pop af
 	ld [CurPartySpecies], a
@@ -168,7 +168,7 @@
 	ld a, $1
 	ld [wBoxAlignment], a
 	ld de, vTiles2
-	predef Predef_GetAnimatedFrontpic
+	predef GetAnimatedFrontpic
 	xor a
 	ld [wBoxAlignment], a
 	ret
--- a/engine/evolve.asm
+++ b/engine/evolve.asm
@@ -6,7 +6,7 @@
 	ld c, a
 	ld b, SET_FLAG
 	call EvoFlagAction
-Predef_EvolveAfterBattle: ; 421e6
+EvolveAfterBattle: ; 421e6
 	xor a
 	ld [wMonTriedToEvolve], a
 	dec a
@@ -55,7 +55,7 @@
 	push hl
 	xor a
 	ld [MonType], a
-	predef Predef_CopyPkmnToTempMon
+	predef CopyPkmnToTempMon
 	pop hl
 
 .loop
@@ -265,7 +265,7 @@
 	ld hl, TempMonExp + 2
 	ld de, TempMonMaxHP
 	ld b, $1
-	predef Predef_CalcPkmnStats
+	predef CalcPkmnStats
 
 	ld a, [CurPartyMon]
 	ld hl, PartyMons
@@ -301,7 +301,7 @@
 	ld [wd265], a
 	xor a
 	ld [MonType], a
-	call Predef_LearnLevelMoves
+	call LearnLevelMoves
 	ld a, [wd265]
 	dec a
 	call SetSeenAndCaughtMon
@@ -311,7 +311,7 @@
 	jr nz, .skip_unown
 
 	ld hl, TempMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	callfar UpdateUnownDex
 
 .skip_unown
@@ -429,7 +429,7 @@
 ; 0x42487
 
 
-Predef_LearnLevelMoves: ; 42487
+LearnLevelMoves: ; 42487
 	ld a, [wd265]
 	ld [CurPartySpecies], a
 	dec a
@@ -484,7 +484,7 @@
 	ld [wd265], a
 	call GetMoveName
 	call CopyName1
-	predef Predef_LearnMove
+	predef LearnMove
 	pop hl
 	jr .find_move
 
@@ -495,7 +495,7 @@
 ; 424e1
 
 
-Predef_FillMoves: ; 424e1
+FillMoves: ; 424e1
 ; Fill in moves at de for CurPartySpecies at CurPartyLevel
 
 	push hl
@@ -621,7 +621,7 @@
 EvoFlagAction: ; 42577
 	push de
 	ld d, $0
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	pop de
 	ret
 ; 42581
--- a/engine/health.asm
+++ b/engine/health.asm
@@ -52,7 +52,7 @@
 	farcall RestoreAllPP
 	ret
 
-Predef_ComputeHPBarPixels: ; c699
+ComputeHPBarPixels: ; c699
 ; e = bc * (6 * 8) / de
 	ld a, b
 	or c
@@ -103,7 +103,7 @@
 	ld e, 0
 	ret
 
-Predef_AnimateHPBar: ; c6e0
+AnimateHPBar: ; c6e0
 	call WaitBGMap
 	call _AnimateHPBar
 	call WaitBGMap
--- a/engine/intro_menu.asm
+++ b/engine/intro_menu.asm
@@ -941,24 +941,24 @@
 
 Intro_PrepTrainerPic: ; 619c
 	ld de, vTiles2
-	farcall Predef_GetTrainerPic
+	farcall GetTrainerPic
 	xor a
 	ld [hGraphicStartTile], a
 	hlcoord 6, 4
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ret
 ; 61b4
 
 ShrinkFrame: ; 61b4
 	ld de, vTiles2
-	ld c, $31
-	predef Predef_Decompress
+	ld c, 7 * 7
+	predef DecompressGet2bpp
 	xor a
 	ld [hGraphicStartTile], a
 	hlcoord 6, 4
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ret
 ; 61cd
 
--- a/engine/item_effects.asm
+++ b/engine/item_effects.asm
@@ -415,7 +415,7 @@
 	ld [hBattleTurn], a
 	ld [Buffer2], a
 	ld [wNumHits], a
-	predef Predef_PlayBattleAnim
+	predef PlayBattleAnim
 
 	ld a, [wWildMon]
 	and a
@@ -547,7 +547,7 @@
 
 	ld a, [EnemyMonSpecies]
 	ld [wd265], a
-	predef Predef_NewPokedexEntry
+	predef NewPokedexEntry
 
 .skip_pokedex
 	ld a, [BattleType]
@@ -567,7 +567,7 @@
 	ld [MonType], a
 	call ClearSprites
 
-	predef Predef_TryAddMonToParty
+	predef TryAddMonToParty
 
 	farcall SetCaughtData
 
@@ -623,7 +623,7 @@
 .SendToPC:
 	call ClearSprites
 
-	predef Predef_SendPkmnIntoBox
+	predef SendPkmnIntoBox
 
 	farcall SetBoxMonCaughtData
 
@@ -979,7 +979,7 @@
 	ld [MonType], a
 	ld a, [CurBattleMon]
 	ld [CurPartyMon], a
-	farcall Predef_GetGender
+	farcall GetGender
 	jr c, .done1 ; no effect on genderless
 
 	ld d, 0 ; male
@@ -993,7 +993,7 @@
 	ld [CurPartySpecies], a
 	ld a, WILDMON
 	ld [MonType], a
-	farcall Predef_GetGender
+	farcall GetGender
 	jr c, .done2 ; no effect on genderless
 
 	ld d, 0 ; male
@@ -1283,7 +1283,7 @@
 	ld a, MON_STAT_EXP - 1
 	call GetPartyParamLocation
 	ld b, $1
-	predef_jump Predef_CalcPkmnStats
+	predef_jump CalcPkmnStats
 ; ee9f
 
 RareCandy_StatBooster_ExitMenu: ; ee9f
@@ -1422,7 +1422,7 @@
 
 	xor a ; PARTYMON
 	ld [MonType], a
-	predef Predef_CopyPkmnToTempMon
+	predef CopyPkmnToTempMon
 
 	hlcoord 9, 0
 	ld b, 10
@@ -1431,7 +1431,7 @@
 
 	hlcoord 11, 1
 	ld bc, 4
-	predef Predef_PrintTempMonStats
+	predef PrintTempMonStats
 
 	call WaitPressAorB_BlinkCursor
 
@@ -1439,7 +1439,7 @@
 	ld [MonType], a
 	ld a, [CurPartySpecies]
 	ld [wd265], a
-	predef Predef_LearnLevelMoves
+	predef LearnLevelMoves
 
 	xor a
 	ld [wForceEvolution], a
@@ -1645,7 +1645,7 @@
 	ld d, 0
 	ld hl, wBattleParticipantsIncludingFainted
 	ld b, CHECK_FLAG
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	ld a, c
 	and a
 	jr z, .skip_to_revive
@@ -1654,7 +1654,7 @@
 	ld c, a
 	ld hl, wBattleParticipantsNotFainted
 	ld b, SET_FLAG
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 
 .skip_to_revive
 	xor a
@@ -1821,7 +1821,7 @@
 	call AddNTimes
 	ld a, $2
 	ld [wWhichHPBar], a
-	predef_jump Predef_AnimateHPBar
+	predef_jump AnimateHPBar
 
 UseItem_SelectMon: ; f1f9 (3:71f9)
 	call .SelectMon
@@ -2912,7 +2912,7 @@
 	ld [wBattleAnimParam], a
 	ld [hBattleTurn], a
 	ld [wNumHits], a
-	predef Predef_PlayBattleAnim
+	predef PlayBattleAnim
 	ld hl, BlockedTheBallText
 	call PrintText
 	ld hl, DontBeAThiefText
@@ -3059,7 +3059,7 @@
 	call GetPartyParamLocation
 	push hl
 	ld de, Buffer1
-	predef Predef_FillPP
+	predef FillPP
 	pop hl
 	ld bc, MON_PP - MON_MOVES
 	add hl, bc
--- a/engine/learn.asm
+++ b/engine/learn.asm
@@ -1,4 +1,4 @@
-Predef_LearnMove: ; 6508
+LearnMove: ; 6508
 	call LoadTileMapToTempTileMap
 	ld a, [CurPartyMon]
 	ld hl, PartyMonNicknames
@@ -144,7 +144,7 @@
 	hlcoord 5 + 2, 2 + 2
 	ld a, SCREEN_WIDTH * 2
 	ld [Buffer1], a
-	predef Predef_ListMoves
+	predef ListMoves
 	; wMenuData3
 	ld a, $4
 	ld [w2DMenuCursorInitY], a
--- a/engine/link.asm
+++ b/engine/link.asm
@@ -150,7 +150,7 @@
 	ld [wd265], a
 	push hl
 	push de
-	callfar Predef_ConvertMon_1to2
+	callfar ConvertMon_1to2
 	pop de
 	pop hl
 	ld a, [wd265]
@@ -449,7 +449,7 @@
 	pop af
 	ld [rIF], a
 
-	predef Predef_StartBattle
+	predef StartBattle
 
 	ld a, [rIF]
 	ld h, a
@@ -786,7 +786,7 @@
 	add hl, bc
 	ld c, STAT_SATK
 	ld b, TRUE
-	predef Predef_CalcPkmnStatC
+	predef CalcPkmnStatC
 
 	pop bc
 	pop de
@@ -986,7 +986,7 @@
 	push bc
 	push de
 	ld [wd265], a
-	callfar Predef_ConvertMon_1to2
+	callfar ConvertMon_1to2
 	pop de
 	pop bc
 	ld a, [wd265]
@@ -1065,7 +1065,7 @@
 	add hl, bc
 	ld c, STAT_SATK
 	ld b, TRUE
-	predef Predef_CalcPkmnStatC
+	predef CalcPkmnStatC
 	pop bc
 	pop hl
 	ld a, [hQuotient + 1]
@@ -1078,7 +1078,7 @@
 	add hl, bc
 	ld c, STAT_SDEF
 	ld b, TRUE
-	predef Predef_CalcPkmnStatC
+	predef CalcPkmnStatC
 	pop bc
 	pop hl
 	ld a, [hQuotient + 1]
@@ -1355,7 +1355,7 @@
 	hlcoord 0, 15
 	ld b, 1
 	ld c, 18
-	call Predef_LinkTextbox
+	call LinkTextboxAtHL
 	hlcoord 2, 16
 	ld de, .String_Stats_Trade
 	call PlaceString
@@ -1464,7 +1464,7 @@
 	hlcoord 0, 12
 	ld b, 4
 	ld c, 18
-	call Predef_LinkTextbox
+	call LinkTextboxAtHL
 	farcall Link_WaitBGMap
 	ld hl, .Text_CantTradeLastMon
 	bccoord 1, 14
@@ -1486,7 +1486,7 @@
 	hlcoord 0, 12
 	ld b, 4
 	ld c, 18
-	call Predef_LinkTextbox
+	call LinkTextboxAtHL
 	farcall Link_WaitBGMap
 	ld hl, .Text_Abnormal
 	bccoord 1, 14
@@ -1496,7 +1496,7 @@
 	hlcoord 0, 12
 	ld b, 4
 	ld c, 18
-	call Predef_LinkTextbox
+	call LinkTextboxAtHL
 	hlcoord 1, 14
 	ld de, String_TooBadTheTradeWasCanceled
 	call PlaceString
@@ -1641,7 +1641,7 @@
 	hlcoord 0, 12
 	ld b, $4
 	ld c, $12
-	call Predef_LinkTextbox
+	call LinkTextboxAtHL
 	farcall Link_WaitBGMap
 	ld a, [wd002]
 	ld hl, PartySpecies
@@ -1670,7 +1670,7 @@
 	hlcoord 10, 7
 	ld b, 3
 	ld c, 7
-	call Predef_LinkTextbox
+	call LinkTextboxAtHL
 	ld de, String28eab
 	hlcoord 12, 8
 	call PlaceString
@@ -1710,7 +1710,7 @@
 	hlcoord 0, 12
 	ld b, 4
 	ld c, 18
-	call Predef_LinkTextbox
+	call LinkTextboxAtHL
 	hlcoord 1, 14
 	ld de, String_TooBadTheTradeWasCanceled
 	call PlaceString
@@ -1727,7 +1727,7 @@
 	hlcoord 0, 12
 	ld b, 4
 	ld c, 18
-	call Predef_LinkTextbox
+	call LinkTextboxAtHL
 	hlcoord 1, 14
 	ld de, String_TooBadTheTradeWasCanceled
 	call PlaceString
@@ -1884,11 +1884,11 @@
 	ld a, [hLinkPlayerNumber]
 	cp $1
 	jr z, .player_2
-	predef Predef_TradeAnimation
+	predef TradeAnimation
 	jr .done_animation
 
 .player_2
-	predef Predef_TradeAnimationPlayer2
+	predef TradeAnimationPlayer2
 
 .done_animation
 	pop af
@@ -1906,7 +1906,7 @@
 	ld de, TempMonSpecies
 	ld bc, PARTYMON_STRUCT_LENGTH
 	call CopyBytes
-	predef Predef_AddTempmonToParty
+	predef AddTempmonToParty
 	ld a, [PartyCount]
 	dec a
 	ld [CurPartyMon], a
@@ -1957,7 +1957,7 @@
 	hlcoord 0, 12
 	ld b, 4
 	ld c, 18
-	call Predef_LinkTextbox
+	call LinkTextboxAtHL
 	hlcoord 1, 14
 	ld de, String28ebd
 	call PlaceString
@@ -1994,7 +1994,7 @@
 	next "was canceled!@"
 
 
-Predef_LinkTextbox: ; 28eef
+LinkTextboxAtHL: ; 28eef
 	ld d, h
 	ld e, l
 	farcall LinkTextbox
@@ -2016,11 +2016,11 @@
 	hlcoord 0, 0
 	ld b, 6
 	ld c, 18
-	call Predef_LinkTextbox
+	call LinkTextboxAtHL
 	hlcoord 0, 8
 	ld b, 6
 	ld c, 18
-	call Predef_LinkTextbox
+	call LinkTextboxAtHL
 	farcall PlaceTradePartnerNamesAndParty
 	ret
 ; 28f24
@@ -2577,7 +2577,7 @@
 	call GetSRAMBank
 	ld d, $0
 	ld b, CHECK_FLAG
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	call CloseSRAM
 	ld a, c
 	and a
--- a/engine/link_2.asm
+++ b/engine/link_2.asm
@@ -3,7 +3,7 @@
 	dec a
 	ld [CurPartyMon], a
 	call LowVolume
-	predef Predef_StatsScreenInit
+	predef StatsScreenInit
 	ld a, [CurPartyMon]
 	inc a
 	ld [wMenuCursorY], a
@@ -30,6 +30,7 @@
 	call .PlaceBorder
 	pop hl
 	pop bc
+
 	ld de, AttrMap - TileMap
 	add hl, de
 	inc b
@@ -36,7 +37,7 @@
 	inc b
 	inc c
 	inc c
-	ld a, $7
+	ld a, PAL_BG_TEXT
 .row
 	push bc
 	push hl
@@ -51,6 +52,7 @@
 	dec b
 	jr nz, .row
 	ret
+; 4d37e
 
 .PlaceBorder: ; 4d37e
 	push hl
@@ -75,6 +77,7 @@
 	add hl, de
 	dec b
 	jr nz, .loop
+
 	ld a, "┐"
 	ld [hli], a
 	ld a, "│"
@@ -81,6 +84,7 @@
 	call .PlaceRow
 	ld [hl], "└"
 	ret
+; 4d3ab
 
 .PlaceRow: ; 4d3ab
 	ld d, c
--- a/engine/link_trade.asm
+++ b/engine/link_trade.asm
@@ -48,7 +48,7 @@
 	ld l, e
 	push bc
 	push hl
-	call .draw_border
+	call .PlaceBorder
 	pop hl
 	pop bc
 
@@ -58,7 +58,7 @@
 	inc b
 	inc c
 	inc c
-	ld a, $7
+	ld a, PAL_BG_TEXT
 .row
 	push bc
 	push hl
@@ -75,12 +75,12 @@
 	ret
 ; 16d640
 
-.draw_border ; 16d640
+.PlaceBorder ; 16d640
 	push hl
 	ld a, $30
 	ld [hli], a
 	inc a
-	call .fill_row
+	call .PlaceRow
 	inc a
 	ld [hl], a
 	pop hl
@@ -91,7 +91,7 @@
 	ld a, $33
 	ld [hli], a
 	ld a, " "
-	call .fill_row
+	call .PlaceRow
 	ld [hl], $34
 	pop hl
 	ld de, SCREEN_WIDTH
@@ -102,17 +102,17 @@
 	ld a, $35
 	ld [hli], a
 	ld a, $36
-	call .fill_row
+	call .PlaceRow
 	ld [hl], $37
 	ret
 ; 16d66d
 
-.fill_row ; 16d66d
+.PlaceRow ; 16d66d
 	ld d, c
-.loop4
+.row_loop
 	ld [hli], a
 	dec d
-	jr nz, .loop4
+	jr nz, .row_loop
 	ret
 ; 16d673
 
@@ -181,7 +181,7 @@
 	hlcoord 4, 10
 	ld b, 1
 	ld c, 10
-	predef Predef_LinkTextbox
+	predef LinkTextboxAtHL
 	hlcoord 5, 11
 	ld de, .Waiting
 	call PlaceString
--- a/engine/load_pics.asm
+++ b/engine/load_pics.asm
@@ -1,4 +1,4 @@
-Predef_GetUnownLetter: ; 51040
+GetUnownLetter: ; 51040
 ; Return Unown letter in UnownLetter based on DVs at hl
 
 ; Take the middle 2 bits of each DV and place them in order:
@@ -37,7 +37,7 @@
 	ld [hDividend], a
 	ld [hDividend + 1], a
 	ld [hDividend + 2], a
-	ld a, 10
+	ld a, $ff / NUM_UNOWN + 1
 	ld [hDivisor], a
 	ld b, 4
 	call Divide
@@ -48,7 +48,7 @@
 	ld [UnownLetter], a
 	ret
 
-Predef_GetMonFrontpic: ; 51077
+GetMonFrontpic: ; 51077
 	ld a, [CurPartySpecies]
 	ld [CurSpecies], a
 	call IsAPokemon
@@ -60,7 +60,7 @@
 	ld [rSVBK], a
 	ret
 
-Predef_GetAnimatedFrontpic: ; 5108b
+GetAnimatedFrontpic: ; 5108b
 	ld a, [CurPartySpecies]
 	ld [CurSpecies], a
 	call IsAPokemon
@@ -70,7 +70,7 @@
 	xor a
 	ld [hBGMapMode], a
 	call _GetFrontpic
-	call GetAnimatedFrontpic
+	call GetAnimatedEnemyFrontpic
 	pop af
 	ld [rSVBK], a
 	ret
@@ -131,7 +131,7 @@
 	pop bc
 	ret
 
-GetAnimatedFrontpic: ; 51103
+GetAnimatedEnemyFrontpic: ; 51103
 	ld a, BANK(vTiles3)
 	ld [rVBK], a
 	push hl
@@ -184,18 +184,18 @@
 	and $f0
 	ld c, a
 	push bc
-	call LoadFrontpic
+	call LoadOrientedFrontpic
 	pop bc
 .loop
 	push bc
 	ld c, 0
-	call LoadFrontpic
+	call LoadOrientedFrontpic
 	pop bc
 	dec b
 	jr nz, .loop
 	ret
 
-Predef_GetMonBackpic: ; 5116c
+GetMonBackpic: ; 5116c
 	ld a, [CurPartySpecies]
 	call IsAPokemon
 	ret c
@@ -210,8 +210,7 @@
 	ld [rSVBK], a
 	push de
 
-	; These are assumed to be at the same
-	; address in their respective banks.
+	; These are assumed to be at the same address in their respective banks.
 	GLOBAL PokemonPicPointers,  UnownPicPointers
 	ld hl, PokemonPicPointers ; UnownPicPointers
 	ld a, b
@@ -311,7 +310,7 @@
 	call FarDecompress
 	ret
 
-Predef_GetTrainerPic: ; 5120d
+GetTrainerPic: ; 5120d
 	ld a, [TrainerClass]
 	and a
 	ret z
@@ -353,7 +352,7 @@
 	ld [hBGMapMode], a
 	ret
 
-Predef_Decompress: ; 5125d
+DecompressGet2bpp: ; 5125d
 ; Decompress lz data from b:hl to scratch space at 6:d000, then copy it to address de.
 
 	ld a, [rSVBK]
@@ -414,6 +413,7 @@
 	ret
 
 PadFrontpic: ; 512ab
+; pads frontpic to fill 7x7 box
 	ld a, b
 	cp 6
 	jr z, .six
@@ -422,7 +422,7 @@
 
 .seven_loop
 	ld c, $70
-	call LoadFrontpic
+	call LoadOrientedFrontpic
 	dec b
 	jr nz, .seven_loop
 	ret
@@ -436,7 +436,7 @@
 	xor a
 	call .Fill
 	ld c, $60
-	call LoadFrontpic
+	call LoadOrientedFrontpic
 	dec b
 	jr nz, .six_loop
 	ret
@@ -450,7 +450,7 @@
 	xor a
 	call .Fill
 	ld c, $50
-	call LoadFrontpic
+	call LoadOrientedFrontpic
 	dec b
 	jr nz, .five_loop
 	ld c, $70
@@ -464,7 +464,7 @@
 	jr nz, .Fill
 	ret
 
-LoadFrontpic: ; 512f2
+LoadOrientedFrontpic: ; 512f2
 	ld a, [wBoxAlignment]
 	and a
 	jr nz, .x_flip
--- a/engine/mart.asm
+++ b/engine/mart.asm
@@ -525,7 +525,7 @@
 ; 15d97
 
 MartConfirmPurchase: ; 15d97
-	predef Predef_PartyMonItemName
+	predef PartyMonItemName
 	ld a, MARTTEXT_COSTS_THIS_MUCH
 	call LoadBuyMenuText
 	call YesNoBox
@@ -863,7 +863,7 @@
 	ld a, [wMartItemID]
 	ld hl, NumItems
 	call TossItem
-	predef Predef_PartyMonItemName
+	predef PartyMonItemName
 	hlcoord 1, 14
 	lb bc, 3, 18
 	call ClearBox
--- a/engine/mon_stats.asm
+++ b/engine/mon_stats.asm
@@ -1,8 +1,8 @@
-Predef_DrawPlayerHP: ; 50b0a
+DrawPlayerHP: ; 50b0a
 	ld a, $1
 	jr DrawHP
 
-Predef_DrawEnemyHP: ; 50b0e
+DrawEnemyHP: ; 50b0e
 	ld a, $2
 
 DrawHP: ; 50b10
@@ -43,7 +43,7 @@
 	ld c, e
 
 .not_boxmon
-	predef Predef_ComputeHPBarPixels
+	predef ComputeHPBarPixels
 	ld a, 6
 	ld d, a
 	ld c, a
@@ -82,7 +82,7 @@
 	pop de
 	ret
 
-Predef_PrintTempMonStats: ; 50b7b
+PrintTempMonStats: ; 50b7b
 ; Print TempMon's stats at hl, with spacing bc.
 	push bc
 	push hl
@@ -121,7 +121,7 @@
 	next "SPEED"
 	next "@"
 
-Predef_GetGender: ; 50bdd
+GetGender: ; 50bdd
 ; Return the gender of a given monster (CurPartyMon/CurOTMon/CurWildMon).
 ; When calling this function, a should be set to an appropriate MonType value.
 
@@ -235,7 +235,7 @@
 	scf
 	ret
 
-Predef_ListMovePP: ; 50c50
+ListMovePP: ; 50c50
 	ld a, [wNumMoves]
 	inc a
 	ld c, a
@@ -335,7 +335,7 @@
 	jr nz, .loop
 	ret
 
-UnusedPredef22:
+Unused_PlaceEnemyHPLevel:
 	push hl
 	push hl
 	ld hl, PartyMonNicknames
@@ -343,7 +343,7 @@
 	call GetNick
 	pop hl
 	call PlaceString
-	call Predef_CopyPkmnToTempMon
+	call CopyPkmnToTempMon
 	pop hl
 	ld a, [CurPartySpecies]
 	cp EGG
@@ -352,7 +352,7 @@
 	ld bc, -12
 	add hl, bc
 	ld b, $0
-	call Predef_DrawEnemyHP
+	call DrawEnemyHP
 	pop hl
 	ld bc, 5
 	add hl, bc
@@ -363,7 +363,7 @@
 .egg
 	ret
 
-Predef_PlaceStatusString: ; 50d0a
+PlaceStatusString: ; 50d0a
 	push de
 	inc de
 	inc de
@@ -373,7 +373,7 @@
 	ld a, [de]
 	or b
 	pop de
-	jr nz, Predef_PlaceNonFaintStatus
+	jr nz, PlaceNonFaintStatus
 	push de
 	ld de, FntString
 	call CopyStatusString
@@ -396,7 +396,7 @@
 	ld [hl], a
 	ret
 
-Predef_PlaceNonFaintStatus: ; 50d2e
+PlaceNonFaintStatus: ; 50d2e
 	push de
 	ld a, [de]
 	ld de, PsnString
@@ -430,7 +430,7 @@
 FrzString: db "FRZ@"
 ParString: db "PAR@"
 
-Predef_ListMoves: ; 50d6f
+ListMoves: ; 50d6f
 ; List moves at hl, spaced every [Buffer1] tiles.
 	ld de, wListMoves_MoveIndicesBuffer
 	ld b, $0
--- a/engine/mystery_gift.asm
+++ b/engine/mystery_gift.asm
@@ -1117,7 +1117,7 @@
 	ld d, $0
 	ld b, CHECK_FLAG
 	ld hl, sMysteryGiftDecorationsReceived
-	predef_id Predef_SmallFarFlagAction
+	predef_id SmallFarFlagAction
 	push hl
 	push bc
 	call Predef
@@ -1129,7 +1129,7 @@
 	ret nz
 	call GetMysteryGiftBank
 	ld b, SET_FLAG
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	call CloseSRAM
 	xor a
 	ret
@@ -1142,7 +1142,7 @@
 	ld d, $0
 	ld b, CHECK_FLAG
 	ld hl, sMysteryGiftDecorationsReceived
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	ld a, c
 	and a
 	pop bc
--- a/engine/namingscreen.asm
+++ b/engine/namingscreen.asm
@@ -109,7 +109,7 @@
 	inc de
 	hlcoord 5, 4
 	call PlaceString
-	farcall Predef_GetGender
+	farcall GetGender
 	jr c, .genderless
 	ld a, "♂"
 	jr nz, .place_gender
--- a/engine/npctrade.asm
+++ b/engine/npctrade.asm
@@ -59,7 +59,7 @@
 	push af
 	ld a, [wcf64]
 	push af
-	predef Predef_TradeAnimation
+	predef TradeAnimation
 	pop af
 	ld [wcf64], a
 	pop af
@@ -80,12 +80,12 @@
 	cp TRADE_MALE_ONLY
 	jr z, .check_male
 
-	farcall Predef_GetGender
+	farcall GetGender
 	jr nz, .not_matching
 	jr .matching
 
 .check_male
-	farcall Predef_GetGender
+	farcall GetGender
 	jr z, .not_matching
 
 .matching
@@ -101,7 +101,7 @@
 	ld hl, wTradeFlags
 	ld a, [wJumptableIndex]
 	ld c, a
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	ld a, c
 	and a
 	ret
@@ -188,7 +188,7 @@
 	ld [MonType], a
 	ld [wPokemonWithdrawDepositParameter], a
 	callfar RemoveMonFromPartyOrBox
-	predef Predef_TryAddMonToParty
+	predef TryAddMonToParty
 
 	ld e, TRADE_DIALOG
 	call GetTradeAttribute
--- a/engine/party_menu.asm
+++ b/engine/party_menu.asm
@@ -189,7 +189,7 @@
 	ld d, a
 	ld a, [hli]
 	ld e, a
-	predef Predef_ComputeHPBarPixels
+	predef ComputeHPBarPixels
 	ret
 ; 50138
 
@@ -298,7 +298,7 @@
 	ld e, l
 	ld d, h
 	pop hl
-	call Predef_PlaceStatusString
+	call PlaceStatusString
 
 .next
 	pop hl
@@ -330,7 +330,7 @@
 	add hl, de
 	ld a, [hl]
 	ld [CurPartySpecies], a
-	predef Predef_CanLearnTMHMMove
+	predef CanLearnTMHMMove
 	pop hl
 	call .PlaceAbleNotAble
 	call PlaceString
@@ -469,7 +469,7 @@
 	ld [CurPartyMon], a
 	xor a
 	ld [MonType], a
-	call Predef_GetGender
+	call GetGender
 	ld de, .unknown
 	jr c, .got_gender
 	ld de, .male
--- a/engine/pic_animation.asm
+++ b/engine/pic_animation.asm
@@ -1,6 +1,6 @@
 ; Pic animation arrangement.
 
-UnusedPredef_AnimateMon_Slow_Normal: ; d0000
+Unused_AnimateMon_Slow_Normal: ; d0000
 	hlcoord 12, 0
 	ld a, [wBattleMode]
 	cp WILD_BATTLE
@@ -7,13 +7,13 @@
 	jr z, .wild
 	ld e, ANIM_MON_SLOW
 	ld d, $0
-	call Predef_AnimateFrontpic
+	call AnimateFrontpic
 	ret
 
 .wild
 	ld e, ANIM_MON_NORMAL
 	ld d, $0
-	call Predef_AnimateFrontpic
+	call AnimateFrontpic
 	ret
 ; d001a
 
@@ -20,7 +20,7 @@
 AnimateMon_Menu: ; d001a
 	ld e, ANIM_MON_MENU
 	ld d, $0
-	call Predef_AnimateFrontpic
+	call AnimateFrontpic
 	ret
 ; d0022
 
@@ -27,7 +27,7 @@
 AnimateMon_Trade: ; d0022
 	ld e, ANIM_MON_TRADE
 	ld d, $0
-	call Predef_AnimateFrontpic
+	call AnimateFrontpic
 	ret
 ; d002a
 
@@ -34,7 +34,7 @@
 AnimateMon_Evolve: ; d002a
 	ld e, ANIM_MON_EVOLVE
 	ld d, $0
-	call Predef_AnimateFrontpic
+	call AnimateFrontpic
 	ret
 ; d0032
 
@@ -41,7 +41,7 @@
 AnimateMon_Hatch: ; d0032
 	ld e, ANIM_MON_HATCH
 	ld d, $0
-	call Predef_AnimateFrontpic
+	call AnimateFrontpic
 	ret
 ; d003a
 
@@ -48,7 +48,7 @@
 AnimateMon_Unused: ; d003a
 	ld e, ANIM_MON_UNUSED
 	ld d, $0
-	call Predef_AnimateFrontpic
+	call AnimateFrontpic
 	ret
 ; d0042
 
@@ -86,10 +86,10 @@
 .Egg2:   pokeanim Idle, Play
 
 
-Predef_AnimateFrontpic: ; d008e
+AnimateFrontpic: ; d008e
 	call AnimateMon_CheckIfPokemon
 	ret c
-	call Predef_LoadMonAnimation
+	call LoadMonAnimation
 .loop
 	call SetUpPokeAnim
 	push af
@@ -99,7 +99,7 @@
 	ret
 ; d00a3
 
-Predef_LoadMonAnimation: ; d00a3
+LoadMonAnimation: ; d00a3
 	push hl
 	ld c, e
 	ld b, 0
@@ -1110,11 +1110,11 @@
 	ret
 ; d0669
 
-UnusedPredef48: ; d0669 Predef 48
+Unused_HOF_AnimateAlignedFrontpic: ; d0669
 	ld a, $1
 	ld [wBoxAlignment], a
 
-Predef_HOF_AnimateFrontpic: ; d066e Predef 49
+HOF_AnimateFrontpic: ; d066e
 	call AnimateMon_CheckIfPokemon
 	jr c, .fail
 	ld h, d
@@ -1122,12 +1122,12 @@
 	push bc
 	push hl
 	ld de, vTiles2
-	predef Predef_GetAnimatedFrontpic
+	predef GetAnimatedFrontpic
 	pop hl
 	pop bc
 	ld d, 0
 	ld e, c
-	call Predef_AnimateFrontpic
+	call AnimateFrontpic
 	xor a
 	ld [wBoxAlignment], a
 	ret
--- a/engine/player_gfx.asm
+++ b/engine/player_gfx.asm
@@ -30,7 +30,7 @@
 	xor a
 	ld [hBGMapMode], a
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	xor a
 	ld [hBGMapThird], a
 	call WaitBGMap
@@ -141,7 +141,7 @@
 	ld b, BANK(ChrisBackpic)
 	ld de, vTiles2 tile $31
 	ld c, 7 * 7
-	predef Predef_Decompress
+	predef DecompressGet2bpp
 	ret
 
 HOF_LoadTrainerFrontpic: ; 88840
@@ -203,7 +203,7 @@
 	ld [hGraphicStartTile], a
 	hlcoord 6, 4
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ret
 
 ChrisPic: ; 888a9
--- a/engine/pokedex.asm
+++ b/engine/pokedex.asm
@@ -443,7 +443,7 @@
 	call Pokedex_GetSelectedMon
 	ld a, [wDexCurrentLocation]
 	ld e, a
-	predef Predef_Pokedex_GetArea
+	predef Pokedex_GetArea
 	call Pokedex_BlackOutBG
 	call DelayFrame
 	xor a
@@ -2367,7 +2367,7 @@
 	ld [CurPartySpecies], a
 	call GetBaseData
 	ld de, vTiles2
-	predef Predef_GetMonFrontpic
+	predef GetMonFrontpic
 	ret
 
 .QuestionMark:
@@ -2520,7 +2520,7 @@
 	ld [CurPartySpecies], a
 	call GetBaseData
 	ld de, vTiles2 tile $00
-	predef Predef_GetMonFrontpic
+	predef GetMonFrontpic
 	pop af
 	ld [UnownLetter], a
 	ret
@@ -2550,7 +2550,7 @@
 	call WaitBGMap
 	call GetBaseData
 	ld de, vTiles2
-	predef Predef_GetMonFrontpic
+	predef GetMonFrontpic
 	ld a, SCGB_POKEDEX
 	call Pokedex_GetSGBLayout
 	ld a, [CurPartySpecies]
--- a/engine/pokegear.asm
+++ b/engine/pokegear.asm
@@ -2362,7 +2362,7 @@
 	ld hl, wVisitedSpawns
 	ld b, CHECK_FLAG
 	ld d, 0
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	ld a, c
 	ret
 
@@ -2471,7 +2471,7 @@
 
 ; 91d11
 
-Predef_Pokedex_GetArea: ; 91d11
+Pokedex_GetArea: ; 91d11
 ; e: Current landmark
 	ld a, [wTownMapPlayerIconLandmark]
 	push af
--- a/engine/print_party.asm
+++ b/engine/print_party.asm
@@ -159,7 +159,7 @@
 
 	xor a
 	ld [MonType], a
-	farcall Predef_CopyPkmnToTempMon
+	farcall CopyPkmnToTempMon
 	hlcoord 0, 7
 	ld b, 9
 	ld c, 18
@@ -215,7 +215,7 @@
 	call Function1dc51a
 	call Function1dc52c
 	ld hl, TempMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	ld hl, wBoxAlignment
 	xor a
 	ld [hl], a
@@ -243,7 +243,7 @@
 	call LoadFontsBattleExtra
 	xor a
 	ld [MonType], a
-	farcall Predef_CopyPkmnToTempMon
+	farcall CopyPkmnToTempMon
 	hlcoord 0, 0
 	ld b, 15
 	ld c, 18
@@ -318,7 +318,7 @@
 ; 1dc52c
 
 Function1dc52c: ; 1dc52c
-	farcall Predef_GetGender
+	farcall GetGender
 	ld a, " "
 	jr c, .got_gender
 	ld a, "♂"
--- a/engine/printer.asm
+++ b/engine/printer.asm
@@ -860,7 +860,7 @@
 	ld [CurPartyMon], a
 	ld a, TEMPMON
 	ld [MonType], a
-	farcall Predef_GetGender
+	farcall GetGender
 	ld a, " "
 	jr c, .got_gender
 	ld a, "♂"
--- a/engine/routines/correcterrorsinplayerparty.asm
+++ b/engine/routines/correcterrorsinplayerparty.asm
@@ -90,7 +90,7 @@
 	ld hl, MON_STAT_EXP - 1
 	add hl, bc
 	ld b, $1
-	predef Predef_CalcPkmnStats
+	predef CalcPkmnStats
 	pop hl
 	ld bc, PARTYMON_STRUCT_LENGTH
 	add hl, bc
--- a/engine/routines/flagpredef.asm
+++ b/engine/routines/flagpredef.asm
@@ -1,4 +1,4 @@
-Predef_SmallFarFlagAction: ; 4d7c1
+SmallFarFlagAction: ; 4d7c1
 ; Perform action b on bit c in flag array hl.
 ; If checking a flag, check flag array d:hl unless d is 0.
 
--- a/engine/routines/newpokedexentry.asm
+++ b/engine/routines/newpokedexentry.asm
@@ -1,4 +1,4 @@
-Predef_NewPokedexEntry: ; fb877
+NewPokedexEntry: ; fb877
 	ld a, [hMapAnims]
 	push af
 	xor a
--- a/engine/routines/placegraphic.asm
+++ b/engine/routines/placegraphic.asm
@@ -1,7 +1,6 @@
-Predef_PlaceGraphic: ; 2ef6e
+PlaceGraphic: ; 2ef6e
 ; Fill wBoxAlignment-aligned box width b height c
 ; with iterating tile starting from hGraphicStartTile at hl.
-; Predef $13
 
 	ld de, SCREEN_WIDTH
 
--- a/engine/routines/placewaitingtext.asm
+++ b/engine/routines/placewaitingtext.asm
@@ -11,7 +11,7 @@
 	jr .proceed
 
 .notinbattle
-	predef Predef_LinkTextbox
+	predef LinkTextboxAtHL
 
 .proceed
 	hlcoord 4, 11
--- a/engine/routines/printitemdescription.asm
+++ b/engine/routines/printitemdescription.asm
@@ -11,7 +11,7 @@
 	pop hl
 	ld a, [wd265]
 	ld [CurSpecies], a
-	predef Predef_PrintMoveDesc
+	predef PrintMoveDesc
 	ret
 
 .not_a_tm
--- a/engine/routines/trademonfrontpic.asm
+++ b/engine/routines/trademonfrontpic.asm
@@ -4,13 +4,13 @@
 	ld de, vTiles2
 	push de
 	push af
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	pop af
 	ld [CurPartySpecies], a
 	ld [CurSpecies], a
 	call GetBaseData
 	pop de
-	predef Predef_GetAnimatedFrontpic
+	predef GetAnimatedFrontpic
 	ret
 
 AnimateTrademonFrontpic: ; 4d81e
@@ -34,5 +34,5 @@
 	hlcoord 7, 2
 	ld d, $0
 	ld e, ANIM_MON_TRADE
-	predef Predef_AnimateFrontpic
+	predef AnimateFrontpic
 	ret
--- a/engine/scripting.asm
+++ b/engine/scripting.asm
@@ -1370,7 +1370,7 @@
 ; script command 0x5f
 
 	call BufferScreen
-	predef Predef_StartBattle
+	predef StartBattle
 	ld a, [wBattleResult]
 	and $3f
 	ld [ScriptVar], a
@@ -2351,7 +2351,7 @@
 	ld [CurPartySpecies], a
 	call GetScriptByte
 	ld [CurPartyLevel], a
-	farcall Predef_GiveEgg
+	farcall GiveEgg
 	ret nc
 	ld a, 2
 	ld [ScriptVar], a
--- a/engine/sgb_layouts.asm
+++ b/engine/sgb_layouts.asm
@@ -1,4 +1,4 @@
-Predef_LoadSGBLayout: ; 864c
+LoadSGBLayout: ; 864c
 	call CheckCGB
 	jp nz, LoadSGBLayoutCGB
 
--- a/engine/specials.asm
+++ b/engine/specials.asm
@@ -38,7 +38,7 @@
 	call FadeToMenu
 	ld a, [ScriptVar]
 	ld [wd265], a
-	farcall Predef_NewPokedexEntry
+	farcall NewPokedexEntry
 	call ExitAllMenus
 	ret
 ; c252
--- a/engine/start_menu.asm
+++ b/engine/start_menu.asm
@@ -591,7 +591,7 @@
 
 TossItemFromPC: ; 129f4
 	push de
-	call Predef_PartyMonItemName
+	call PartyMonItemName
 	farcall _CheckTossableItem
 	ld a, [wItemAttributeParamBuffer]
 	and a
@@ -614,7 +614,7 @@
 	pop hl
 	ld a, [CurItemQuantity]
 	call TossItem
-	call Predef_PartyMonItemName
+	call PartyMonItemName
 	ld hl, .TossedThisMany
 	call MenuTextBox
 	call ExitMenu
@@ -666,7 +666,7 @@
 ; 12a6c
 
 
-Predef_PartyMonItemName: ; 12a6c
+PartyMonItemName: ; 12a6c
 	ld a, [CurItem]
 	ld [wd265], a
 	call GetItemName
@@ -860,7 +860,7 @@
 TryGiveItemToPartymon: ; 12bd9
 
 	call SpeechTextBox
-	call Predef_PartyMonItemName
+	call PartyMonItemName
 	call GetPartyItemLocation
 	ld a, [hl]
 	and a
@@ -1221,7 +1221,7 @@
 	xor a
 	ld [MonType], a
 	call LowVolume
-	predef Predef_StatsScreenInit
+	predef StatsScreenInit
 	call MaxVolume
 	call Call_ExitMenu
 	ld a, 0
@@ -1788,7 +1788,7 @@
 	hlcoord 5, 1
 	call PlaceString
 	push bc
-	farcall Predef_CopyPkmnToTempMon
+	farcall CopyPkmnToTempMon
 	pop hl
 	call PrintLevel
 	ld hl, PlayerHPPal
@@ -1805,7 +1805,7 @@
 	ld [hBGMapMode], a
 	ld [wMoveSwapBuffer], a
 	ld [MonType], a
-	predef Predef_CopyPkmnToTempMon
+	predef CopyPkmnToTempMon
 	ld hl, TempMonMoves
 	ld de, wListMoves_MoveIndicesBuffer
 	ld bc, NUM_MOVES
@@ -1813,9 +1813,9 @@
 	ld a, SCREEN_WIDTH * 2
 	ld [Buffer1], a
 	hlcoord 2, 3
-	predef Predef_ListMoves
+	predef ListMoves
 	hlcoord 10, 4
-	predef Predef_ListMovePP
+	predef ListMovePP
 	call WaitBGMap
 	call SetPalettes
 	ld a, [wNumMoves]
@@ -1859,7 +1859,7 @@
 	ld a, [CurMove]
 	ld b, a
 	hlcoord 2, 12
-	predef Predef_PrintMoveType
+	predef PrintMoveType
 	ld a, [CurMove]
 	dec a
 	ld hl, Moves + MOVE_POWER
@@ -1882,7 +1882,7 @@
 
 .description
 	hlcoord 1, 14
-	predef Predef_PrintMoveDesc
+	predef PrintMoveDesc
 	ld a, $1
 	ld [hBGMapMode], a
 	ret
--- a/engine/stats_screen.asm
+++ b/engine/stats_screen.asm
@@ -7,14 +7,14 @@
 BattleStatsScreenInit: ; 4dc7b (13:5c7b)
 	ld a, [wLinkMode]
 	cp LINK_MOBILE
-	jr nz, Predef_StatsScreenInit
+	jr nz, StatsScreenInit
 
 	ld a, [wBattleMode]
 	and a
-	jr z, Predef_StatsScreenInit
+	jr z, StatsScreenInit
 	jr _MobileStatsScreenInit
 
-Predef_StatsScreenInit: ; 4dc8a
+StatsScreenInit: ; 4dc8a
 	ld hl, StatsScreenMain
 	jr StatsScreenInit_gotaddress
 
@@ -240,7 +240,7 @@
 	jr .done
 
 .breedmon
-	farcall Predef_CopyPkmnToTempMon
+	farcall CopyPkmnToTempMon
 	ld a, [CurPartySpecies]
 	cp EGG
 	jr z, .done
@@ -425,7 +425,7 @@
 	ld a, [hli]
 	ld d, a
 	ld e, [hl]
-	farcall Predef_ComputeHPBarPixels
+	farcall ComputeHPBarPixels
 	ld hl, wCurHPPal
 	call SetHPPal
 	ld b, SCGB_STATS_SCREEN_HP_PALS
@@ -435,7 +435,7 @@
 
 .PlaceGenderChar: ; 4df66 (13:5f66)
 	push hl
-	farcall Predef_GetGender
+	farcall GetGender
 	pop hl
 	ret c
 	ld a, "♂"
@@ -547,7 +547,7 @@
 .PinkPage: ; 4e013 (13:6013)
 	hlcoord 0, 9
 	ld b, $0
-	predef Predef_DrawPlayerHP
+	predef DrawPlayerHP
 	hlcoord 8, 9
 	ld [hl], $41 ; right HP/exp bar end cap
 	ld de, .Status_Type
@@ -569,7 +569,7 @@
 	hlcoord 6, 13
 	push hl
 	ld de, TempMonStatus
-	predef Predef_PlaceStatusString
+	predef PlaceStatusString
 	pop hl
 	jr nz, .done_status
 	jr .StatusOK
@@ -583,7 +583,7 @@
 	call PlaceString
 .done_status
 	hlcoord 1, 15
-	predef Predef_PrintMonTypes
+	predef PrintMonTypes
 	hlcoord 9, 8
 	ld de, SCREEN_WIDTH
 	ld b, 10
@@ -617,7 +617,7 @@
 	ld a, [TempMonLevel]
 	ld b, a
 	ld de, TempMonExp + 2
-	predef Predef_FillInExpBar
+	predef FillInExpBar
 	hlcoord 10, 16
 	ld [hl], $40 ; left exp bar end cap
 	hlcoord 19, 16
@@ -710,11 +710,11 @@
 	hlcoord 8, 10
 	ld a, SCREEN_WIDTH * 2
 	ld [Buffer1], a
-	predef Predef_ListMoves
+	predef ListMoves
 	hlcoord 12, 11
 	ld a, SCREEN_WIDTH * 2
 	ld [Buffer1], a
-	predef Predef_ListMovePP
+	predef ListMovePP
 	ret
 
 .GetItemName: ; 4e189 (13:6189)
@@ -755,7 +755,7 @@
 	jr nz, .BluePageVerticalDivider
 	hlcoord 11, 8
 	ld bc, 6
-	predef Predef_PrintTempMonStats
+	predef PrintTempMonStats
 	ret
 
 .PlaceOTInfo: ; 4e1cc (13:61cc)
@@ -808,7 +808,7 @@
 
 StatsScreen_PlaceFrontpic: ; 4e226 (13:6226)
 	ld hl, TempMonDVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	call StatsScreen_GetAnimationParam
 	jr c, .egg
 	and a
@@ -870,11 +870,11 @@
 	ret c
 	call StatsScreen_LoadTextBoxSpaceGFX
 	ld de, vTiles2 tile $00
-	predef Predef_GetAnimatedFrontpic
+	predef GetAnimatedFrontpic
 	hlcoord 0, 0
 	ld d, $0
 	ld e, ANIM_MON_MENU
-	predef Predef_LoadMonAnimation
+	predef LoadMonAnimation
 	ld hl, wcf64
 	set 6, [hl]
 	ret
@@ -1074,11 +1074,11 @@
 	ld [wBoxAlignment], a
 	call StatsScreen_LoadTextBoxSpaceGFX
 	ld de, vTiles2 tile $00
-	predef Predef_GetAnimatedFrontpic
+	predef GetAnimatedFrontpic
 	pop de
 	hlcoord 0, 0
 	ld d, $0
-	predef Predef_LoadMonAnimation
+	predef LoadMonAnimation
 	ld hl, wcf64
 	set 6, [hl]
 	ret
--- a/engine/tempmon.asm
+++ b/engine/tempmon.asm
@@ -1,4 +1,4 @@
-Predef_CopyPkmnToTempMon: ; 5084a
+CopyPkmnToTempMon: ; 5084a
 ; gets the BaseData of a Pkmn
 ; and copys the PkmnStructure to TempMon
 
@@ -51,7 +51,7 @@
 	add hl, bc
 	push bc
 	ld b, $1
-	predef Predef_CalcPkmnStats
+	predef CalcPkmnStats
 	pop bc
 	ld hl, MON_HP
 	add hl, bc
--- a/engine/time_capsule_2.asm
+++ b/engine/time_capsule_2.asm
@@ -18,7 +18,7 @@
 	ret
 ; fb908
 
-Predef_ConvertMon_1to2: ; fb908
+ConvertMon_1to2: ; fb908
 ; Takes the Gen-1 Pokemon number stored in wd265 and returns the corresponding value from Pokered_MonIndices in wd265.
 	push bc
 	push hl
--- a/engine/tmhm.asm
+++ b/engine/tmhm.asm
@@ -1,4 +1,4 @@
-Predef_CanLearnTMHMMove: ; 11639
+CanLearnTMHMMove: ; 11639
 	ld a, [CurPartySpecies]
 	ld [CurSpecies], a
 	call GetBaseData
@@ -23,7 +23,7 @@
 	ld b, CHECK_FLAG
 	push de
 	ld d, 0
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	pop de
 	ret
 
@@ -33,7 +33,7 @@
 	ret
 ; 1166a
 
-Predef_GetTMHMMove: ; 1166a
+GetTMHMMove: ; 1166a
 	ld a, [wd265]
 	dec a
 	ld hl, TMHMMoves
--- a/engine/tmhm2.asm
+++ b/engine/tmhm2.asm
@@ -38,7 +38,7 @@
 
 GetTMHMItemMove: ; 2c7b6 (b:47b6)
 	call ConvertCurItemIntoCurTMHM
-	predef Predef_GetTMHMMove
+	predef GetTMHMMove
 	ret
 
 AskTeachTMHM: ; 2c7bf (b:47bf)
@@ -118,7 +118,7 @@
 ; 2c867
 
 TeachTMHM: ; 2c867
-	predef Predef_CanLearnTMHMMove
+	predef CanLearnTMHMMove
 
 	push bc
 	ld a, [CurPartyMon]
@@ -141,7 +141,7 @@
 	callfar KnowsMove
 	jr c, .nope
 
-	predef Predef_LearnMove
+	predef LearnMove
 	ld a, b
 	and a
 	jr z, .nope
@@ -258,11 +258,11 @@
 	cp NUM_TMS + NUM_HMS + 1
 	jr nc, TMHM_JoypadLoop
 	ld [wd265], a
-	predef Predef_GetTMHMMove
+	predef GetTMHMMove
 	ld a, [wd265]
 	ld [CurSpecies], a
 	hlcoord 1, 14
-	call Predef_PrintMoveDesc
+	call PrintMoveDesc
 	jp TMHM_JoypadLoop
 
 TMHM_ChooseTMorHM: ; 2c974 (b:4974)
@@ -386,7 +386,7 @@
 	pop af
 	ld [wd265], a
 .okay
-	predef Predef_GetTMHMMove
+	predef GetTMHMMove
 	ld a, [wd265]
 	ld [wPutativeTMHMMove], a
 	call GetMoveName
@@ -451,7 +451,7 @@
 	pop hl
 	ld bc, 3
 	add hl, bc
-	predef Predef_GetTMHMMove
+	predef GetTMHMMove
 	ld a, [wd265]
 	ld [wPutativeTMHMMove], a
 	call GetMoveName
@@ -572,7 +572,7 @@
 	ld [wd265], a
 	ret
 
-Predef_PrintMoveDesc: ; 2cb3e
+PrintMoveDesc: ; 2cb3e
 	push hl
 	ld hl, MoveDescriptions
 	ld a, [CurSpecies]
--- a/engine/trade_animation.asm
+++ b/engine/trade_animation.asm
@@ -9,7 +9,7 @@
 	const TRADEANIMSTATE_3 ; 3
 TRADEANIMJUMPTABLE_LENGTH EQU const_value
 
-Predef_TradeAnimation: ; 28f24
+TradeAnimation: ; 28f24
 	xor a
 	ld [wcf66], a
 	ld hl, wPlayerTrademonSenderName
@@ -60,7 +60,7 @@
 	tradeanim_scroll_out_right
 	tradeanim_end
 
-Predef_TradeAnimationPlayer2: ; 28f63
+TradeAnimationPlayer2: ; 28f63
 	xor a
 	ld [wcf66], a
 	ld hl, wOTTrademonSenderName
@@ -883,13 +883,13 @@
 TradeAnim_GetFrontpic: ; 29491
 	push de
 	push af
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	pop af
 	ld [CurPartySpecies], a
 	ld [CurSpecies], a
 	call GetBaseData
 	pop de
-	predef Predef_GetMonFrontpic
+	predef GetMonFrontpic
 	ret
 
 ; 294a9
@@ -923,7 +923,7 @@
 	xor a
 	ld [hGraphicStartTile], a
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	call WaitBGMap
 	ret
 
--- a/engine/trainer_card.asm
+++ b/engine/trainer_card.asm
@@ -254,7 +254,7 @@
 	lb bc, 5, 7
 	xor a
 	ld [hGraphicStartTile], a
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	ret
 
 ; 252ec (9:52ec)
--- a/engine/types.asm
+++ b/engine/types.asm
@@ -1,4 +1,4 @@
-Predef_PrintMonTypes: ; 5090d
+PrintMonTypes: ; 5090d
 ; Print one or both types of [CurSpecies]
 ; on the stats screen at hl.
 
@@ -24,7 +24,7 @@
 
 .Print:
 	ld b, a
-	jr Predef_PrintType
+	jr PrintType
 
 .hide_type_2
 	; Erase any type name that was here before.
@@ -40,7 +40,7 @@
 ; 5093a
 
 
-Predef_PrintMoveType: ; 5093a
+PrintMoveType: ; 5093a
 ; Print the type of move b at hl.
 
 	push hl
@@ -58,7 +58,7 @@
 	ld b, a
 
 
-Predef_PrintType: ; 50953
+PrintType: ; 50953
 ; Print type b at hl.
 
 	ld a, b
@@ -78,7 +78,7 @@
 ; 50964
 
 
-Predef_GetTypeName: ; 50964
+GetTypeName: ; 50964
 ; Copy the name of type [wd265] to StringBuffer1.
 
 	ld a, [wd265]
--- a/home.asm
+++ b/home.asm
@@ -711,7 +711,7 @@
 	ret z
 
 .sgb
-	predef_jump Predef_LoadSGBLayout
+	predef_jump LoadSGBLayout
 ; 334e
 
 SetHPPal:: ; 334e
@@ -1074,12 +1074,12 @@
 
 	push hl
 	ld de, vTiles2
-	predef Predef_GetMonFrontpic
+	predef GetMonFrontpic
 	pop hl
 	xor a
 	ld [hGraphicStartTile], a
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	xor a
 	ld [wBoxAlignment], a
 	ret
--- a/home/battle.asm
+++ b/home/battle.asm
@@ -130,8 +130,8 @@
 ; 39d4
 
 UpdateBattleHuds:: ; 39d4
-	farcall Predef_UpdatePlayerHUD
-	farcall Predef_UpdateEnemyHUD
+	farcall UpdatePlayerHUD
+	farcall UpdateEnemyHUD
 	ret
 ; 39e1
 
--- a/home/init.asm
+++ b/home/init.asm
@@ -166,7 +166,7 @@
 
 	call DelayFrame
 
-	predef Predef_InitSGBBorder ; SGB init
+	predef InitSGBBorder ; SGB init
 
 	call MapSetup_Sound_Off
 	xor a
--- a/home/pokedex_flags.asm
+++ b/home/pokedex_flags.asm
@@ -31,7 +31,7 @@
 
 PokedexFlagAction:: ; 33a1
 	ld d, 0
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 	ld a, c
 	and a
 	ret
--- a/mobile/mobile_22.asm
+++ b/mobile/mobile_22.asm
@@ -1227,7 +1227,7 @@
 	xor a
 	ld [CurPartySpecies], a
 	ld de, vTiles2 tile $37
-	farcall Predef_GetTrainerPic
+	farcall GetTrainerPic
 	pop bc
 	ret
 ; 897d5
@@ -1259,7 +1259,7 @@
 	ld [hGraphicStartTile], a
 	hlcoord 12, 3
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	call Function8963d
 	pop bc
 	ret
--- a/mobile/mobile_40.asm
+++ b/mobile/mobile_40.asm
@@ -1985,7 +1985,7 @@
 	ld a, SCREEN_WIDTH * 2
 	ld [Buffer1], a
 	hlcoord 2, 10
-	predef Predef_ListMoves
+	predef ListMoves
 	ret
 ; 100c98
 
@@ -6794,7 +6794,7 @@
 	ld bc, PARTYMON_STRUCT_LENGTH
 	ld hl, PartyMon1DVs
 	call AddNTimes
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	farcall UpdateUnownDex
 	ld a, [wFirstUnownSeen]
 	and a
--- a/mobile/mobile_42.asm
+++ b/mobile/mobile_42.asm
@@ -290,13 +290,13 @@
 MobileTradeAnim_GetFrontpic: ; 1081e9
 	push de
 	push af
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	pop af
 	ld [CurPartySpecies], a
 	ld [CurSpecies], a
 	call GetBaseData
 	pop de
-	predef Predef_GetMonFrontpic
+	predef GetMonFrontpic
 	ret
 ; 108201
 
@@ -303,13 +303,13 @@
 Function108201: ; 108201
 	push de
 	push af
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	pop af
 	ld [CurPartySpecies], a
 	ld [CurSpecies], a
 	call GetBaseData
 	pop de
-	predef Predef_GetAnimatedFrontpic
+	predef GetAnimatedFrontpic
 	ret
 ; 108219
 
@@ -318,7 +318,7 @@
 	hlcoord 7, 2
 	ld d, $0
 	ld e, ANIM_MON_TRADE
-	predef Predef_AnimateFrontpic
+	predef AnimateFrontpic
 	ret
 ; 108229
 
@@ -327,7 +327,7 @@
 	hlcoord 7, 2
 	ld d, $0
 	ld e, ANIM_MON_TRADE
-	predef Predef_LoadMonAnimation
+	predef LoadMonAnimation
 	ret
 ; 108239
 
@@ -1238,7 +1238,7 @@
 	xor a
 	ld [hGraphicStartTile], a
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	call WaitBGMap
 	ret
 ; 10898a
@@ -1252,7 +1252,7 @@
 	xor a
 	ld [hGraphicStartTile], a
 	lb bc, 7, 7
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	call WaitBGMap
 	ret
 ; 1089a8
--- a/mobile/mobile_46.asm
+++ b/mobile/mobile_46.asm
@@ -6688,7 +6688,7 @@
 	call PlaceString
 	xor a
 	ld [MonType], a
-	farcall Predef_GetGender
+	farcall GetGender
 	hlcoord 1, 4
 	ld a, [CurPartySpecies]
 	ld bc, wcd2f
@@ -7146,7 +7146,7 @@
 	pop de
 	push de
 	ld b, OTPARTYMON
-	predef Predef_CalcPkmnStats
+	predef CalcPkmnStats
 	pop de
 	ld h, d
 	ld l, e
@@ -7565,7 +7565,7 @@
 	ld hl, $c60d + MON_STAT_EXP - 1
 	ld de, $c60d + MON_MAXHP
 	ld b, $1
-	predef Predef_CalcPkmnStats
+	predef CalcPkmnStats
 	ld de, $c60d + MON_MAXHP
 	ld hl, $c60d + MON_HP
 	ld a, [de]
--- a/mobile/mobile_5f.asm
+++ b/mobile/mobile_5f.asm
@@ -412,7 +412,7 @@
 	dec a
 	ld bc, PARTYMON_STRUCT_LENGTH
 	call AddNTimes
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	callfar UpdateUnownDex
 	ld a, [wFirstUnownSeen]
 	and a
@@ -1498,7 +1498,7 @@
 	add hl, de
 	ld e, l
 	ld d, h
-	farcall Predef_HOF_AnimateFrontpic
+	farcall HOF_AnimateFrontpic
 	pop af
 	ld [rSVBK], a
 	call Function17e349
@@ -1530,12 +1530,12 @@
 	ld d, a
 	push de
 	ld de, vTiles2
-	farcall Predef_GetTrainerPic
+	farcall GetTrainerPic
 	pop hl
 	decoord 0, 0
 	add hl, de
 	ld bc, $707
-	predef Predef_PlaceGraphic
+	predef PlaceGraphic
 	pop af
 	ld [rSVBK], a
 	call Function17e349
@@ -2337,7 +2337,7 @@
 	ld [MonType], a
 	push hl
 	push bc
-	predef Predef_TryAddMonToParty
+	predef TryAddMonToParty
 	farcall SetCaughtData
 	pop bc
 	pop hl
@@ -2442,7 +2442,7 @@
 	ld e, l
 	push hl
 	ld b, $0
-	farcall Predef_CalcPkmnStats
+	farcall CalcPkmnStats
 	ld a, [PartyCount]
 	dec a
 	ld hl, PartyMon1HP
@@ -2508,7 +2508,7 @@
 	ld d, h
 	ld e, l
 	pop hl
-	predef Predef_FillPP
+	predef FillPP
 	pop hl
 	pop bc
 	jp asm_17e0ee
@@ -2531,7 +2531,7 @@
 	push bc
 	push hl
 	farcall LoadEnemyMon
-	farcall Predef_SendPkmnIntoBox
+	farcall SendPkmnIntoBox
 	farcall SetBoxMonCaughtData
 	pop hl
 	pop bc
@@ -2622,7 +2622,7 @@
 	push hl
 	ld hl, sBoxMon1Moves
 	ld de, sBoxMon1PP
-	predef Predef_FillPP
+	predef FillPP
 	call CloseSRAM
 	pop hl
 	pop bc
--- a/engine/battle/anim_hp_bar.asm
+++ b/engine/battle/anim_hp_bar.asm
@@ -67,7 +67,7 @@
 	ld a, [hli]
 	ld b, a
 	pop hl
-	call Predef_ComputeHPBarPixels
+	call ComputeHPBarPixels
 	ld a, e
 	ld [wCurHPBarPixels], a
 
@@ -79,7 +79,7 @@
 	ld e, a
 	ld a, [wCurHPAnimMaxHP + 1]
 	ld d, a
-	call Predef_ComputeHPBarPixels
+	call ComputeHPBarPixels
 	ld a, e
 	ld [wNewHPBarPixels], a
 
@@ -183,11 +183,11 @@
 	ld c, a
 	ld a, [hli]
 	ld b, a
 	; This routine is buggy. The result from Predef_ComputeHPBarPixels is stored
 	; in e. However, the pop de opcode deletes this result before it is even
 	; used. The game then proceeds as though it never deleted that output.
 	; To fix, uncomment the line below.
-	call Predef_ComputeHPBarPixels
+	call ComputeHPBarPixels
 	; ld a, e
 	pop bc
 	pop de
@@ -227,7 +227,7 @@
 	ld e, a
 	ld a, [wCurHPAnimMaxHP + 1]
 	ld d, a
-	call Predef_ComputeHPBarPixels
+	call ComputeHPBarPixels
 	ld c, e
 	ld d, HP_BAR_LENGTH
 	ld a, [wWhichHPBar]
@@ -183,11 +183,11 @@
 	ld a, [hli]
 	ld b, a
-	; This routine is buggy. The result from Predef_ComputeHPBarPixels is stored
+	; This routine is buggy. The result from ComputeHPBarPixels is stored
 	; in e. However, the pop de opcode deletes this result before it is even
 	; used. The game then proceeds as though it never deleted that output.
--- a/engine/battle/effect_commands.asm
+++ b/engine/battle/effect_commands.asm
@@ -182,7 +182,7 @@
 	call StdBattleTextBox
 	call CantMove
 	call UpdateBattleMonInParty
-	ld hl, Predef_UpdatePlayerHUD
+	ld hl, UpdatePlayerHUD
 	call CallBattleCore
 	ld a, $1
 	ld [hBGMapMode], a
@@ -433,7 +433,7 @@
 	call StdBattleTextBox
 	call CantMove
 	call UpdateEnemyMonInParty
-	ld hl, Predef_UpdateEnemyHUD
+	ld hl, UpdateEnemyHUD
 	call CallBattleCore
 	ld a, $1
 	ld [hBGMapMode], a
@@ -672,7 +672,7 @@
 	and 1 << SUBSTATUS_FLYING | 1 << SUBSTATUS_UNDERGROUND
 	call z, PlayFXAnimID
 
-	ld hl, Predef_UpdatePlayerHUD
+	ld hl, UpdatePlayerHUD
 	call CallBattleCore
 	ld a, $1
 	ld [hBGMapMode], a
@@ -1538,11 +1538,11 @@
 	ld hl, EnemyMonType1
 	ld a, [hBattleTurn]
 	and a
-	jr z, Predef_CheckTypeMatchup
+	jr z, CheckTypeMatchup
 	ld hl, BattleMonType1
-Predef_CheckTypeMatchup: ; 347d3
+CheckTypeMatchup: ; 347d3
 ; There is an incorrect assumption about this function made in the AI related code: when
 ; the AI calls Predef_CheckTypeMatchup (not BattleCheckTypeMatchup), it assumes that placing
 ; the offensive type in a will make this function do the right thing. Since a is overwritten,
 ; this assumption is incorrect. A simple fix would be to load the move type for the
 ; current move into a in BattleCheckTypeMatchup, before falling through, which is
@@ -2621,7 +2621,7 @@
 	ld [Buffer6], a
 	ld h, b
 	ld l, c
-	predef Predef_AnimateHPBar
+	predef AnimateHPBar
 	call RefreshBattleHuds
 
 	call BattleCommand_SwitchTurn
@@ -4015,7 +4015,7 @@
 	ld a, $1
 	ld [wWhichHPBar], a
 	hlcoord 10, 9
-	predef Predef_AnimateHPBar
+	predef AnimateHPBar
 	ld hl, EnemyMonHP
 	ld a, [hli]
 	ld [Buffer4], a
@@ -4030,7 +4030,7 @@
 	ld [wWhichHPBar], a
 	call ResetDamage
 	hlcoord 2, 2
-	predef Predef_AnimateHPBar
+	predef AnimateHPBar
 	farcall _UpdateBattleHUDs
 
 	ld hl, SharedPainText
@@ -4172,7 +4172,7 @@
 
 	ld a, [hl]
 	ld [wNamedObjectIndexBuffer], a
-	predef Predef_GetTypeName
+	predef GetTypeName
 	ld hl, TransformedTypeText
 	jp StdBattleTextBox
 
@@ -4711,7 +4711,7 @@
 	ld c, 3
 	call DelayFrames
 
-	callfar Predef_PlayBattleAnim
+	callfar PlayBattleAnim
 
 	ret
 
@@ -4773,7 +4773,7 @@
 	hlcoord 2, 2
 	xor a
 	ld [wWhichHPBar], a
-	predef Predef_AnimateHPBar
+	predef AnimateHPBar
 .did_no_damage
 	jp RefreshBattleHuds
 
@@ -4833,7 +4833,7 @@
 	hlcoord 10, 9
 	ld a, $1
 	ld [wWhichHPBar], a
-	predef Predef_AnimateHPBar
+	predef AnimateHPBar
 .did_no_damage
 	jp RefreshBattleHuds
 
@@ -5301,7 +5301,7 @@
 	xor a
 .hp_bar
 	ld [wWhichHPBar], a
-	predef Predef_AnimateHPBar
+	predef AnimateHPBar
 	call RefreshBattleHuds
 	jp UpdateBattleMonInParty
 
@@ -6239,11 +6239,11 @@
 
 
 BattleCommand_RaiseSubNoAnim: ; 365af
-	ld hl, Predef_GetBattleMonBackpic
+	ld hl, GetBattleMonBackpic
 	ld a, [hBattleTurn]
 	and a
 	jr z, .PlayerTurn
-	ld hl, Predef_GetEnemyMonFrontpic
+	ld hl, GetEnemyMonFrontpic
 .PlayerTurn:
 	xor a
 	ld [hBGMapMode], a
@@ -7525,7 +7525,7 @@
 	xor a
 .animate_hp_bar
 	ld [wWhichHPBar], a
-	predef Predef_AnimateHPBar
+	predef AnimateHPBar
 	call RefreshBattleHuds
 	ld hl, RecoilText
 	jp StdBattleTextBox
@@ -8227,7 +8227,7 @@
 	inc de
 	ld [de], a
 	ld [wNamedObjectIndexBuffer], a
-	farcall Predef_GetTypeName
+	farcall GetTypeName
 	call AnimateCurrentMove
 	ld hl, TransformedTypeText
 	jp StdBattleTextBox
@@ -9856,7 +9856,7 @@
 	push hl
 	push de
 	push bc
-	callfar Predef_PlayBattleAnim
+	callfar PlayBattleAnim
 	pop bc
 	pop de
 	pop hl
@@ -9878,7 +9878,7 @@
 	push bc
 	call BattleCommand_SwitchTurn
 
-	callfar Predef_PlayBattleAnim
+	callfar PlayBattleAnim
 
 	call BattleCommand_SwitchTurn
 	pop bc
@@ -1538,11 +1538,11 @@
 ; There is an incorrect assumption about this function made in the AI related code: when
-; the AI calls Predef_CheckTypeMatchup (not BattleCheckTypeMatchup), it assumes that placing
+; the AI calls CheckTypeMatchup (not BattleCheckTypeMatchup), it assumes that placing
 ; the offensive type in a will make this function do the right thing. Since a is overwritten,
 ; this assumption is incorrect. A simple fix would be to load the move type for the
--- a/engine/move_mon.asm
+++ b/engine/move_mon.asm
@@ -1,4 +1,4 @@
-Predef_TryAddMonToParty: ; d88c
+TryAddMonToParty: ; d88c
 ; Check if to copy wild Pkmn or generate new Pkmn
 	; Whose is it?
 	ld de, PartyCount
@@ -120,7 +120,7 @@
 	endr
 	ld [hl], a
 	ld [Buffer1], a
-	predef Predef_FillMoves
+	predef FillMoves
 
 .next
 	pop de
@@ -195,7 +195,7 @@
 	push de
 	inc hl
 	inc hl
-	call Predef_FillPP
+	call FillPP
 	pop de
 	pop hl
 rept 4
@@ -224,7 +224,7 @@
 	ld a, $1
 	ld c, a
 	ld b, FALSE
-	call Predef_CalcPkmnStatC
+	call CalcPkmnStatC
 	ld a, [hProduct + 2]
 	ld [de], a
 	inc de
@@ -297,7 +297,7 @@
 	ld bc, MON_STAT_EXP - 1
 	add hl, bc
 	ld b, $0 ; if b = 1, then stat calculation takes stat exp into account.
-	call Predef_CalcPkmnStats
+	call CalcPkmnStats
 
 .next3
 	ld a, [MonType]
@@ -311,7 +311,7 @@
 	dec a
 	ld bc, PARTYMON_STRUCT_LENGTH
 	call AddNTimes
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	callfar UpdateUnownDex
 
 .done
@@ -319,7 +319,7 @@
 	ret
 ; da6d
 
-Predef_FillPP: ; da6d
+FillPP: ; da6d
 	push bc
 	ld b, NUM_MOVES
 .loop
@@ -350,7 +350,7 @@
 	ret
 ; da96
 
-Predef_AddTempmonToParty: ; da96
+AddTempmonToParty: ; da96
 	ld hl, PartyCount
 	ld a, [hl]
 	cp PARTY_LENGTH
@@ -422,7 +422,7 @@
 	dec a
 	ld bc, PARTYMON_STRUCT_LENGTH
 	call AddNTimes
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	callfar UpdateUnownDex
 	ld a, [wFirstUnownSeen]
 	and a
@@ -434,7 +434,7 @@
 	and a
 	ret
 
-Predef_SendGetPkmnIntoFromBox: ; db3f
+SendGetPkmnIntoFromBox: ; db3f
 ; Sents/Gets Pkmn into/from Box depending on Parameter
 ; wPokemonWithdrawDepositParameter == 0: get Pkmn into Party
 ; wPokemonWithdrawDepositParameter == 1: sent Pkmn into Box
@@ -597,7 +597,7 @@
 	srl a
 	add $2
 	ld [MonType], a
-	predef Predef_CopyPkmnToTempMon
+	predef CopyPkmnToTempMon
 	callfar CalcLevel
 	ld a, d
 	ld [CurPartyLevel], a
@@ -617,7 +617,7 @@
 
 	push bc
 	ld b, $1
-	call Predef_CalcPkmnStats
+	call CalcPkmnStats
 	pop bc
 
 	ld a, [wPokemonWithdrawDepositParameter]
@@ -830,7 +830,7 @@
 	add hl, bc
 	push bc
 	ld b, $1
-	call Predef_CalcPkmnStats
+	call CalcPkmnStats
 	ld hl, PartyMon1Moves
 	ld a, [PartyCount]
 	dec a
@@ -840,7 +840,7 @@
 	ld e, l
 	ld a, $1
 	ld [Buffer1], a
-	predef Predef_FillMoves
+	predef FillMoves
 	ld a, [PartyCount]
 	dec a
 	ld [CurPartyMon], a
@@ -904,7 +904,7 @@
 	ld bc, BOXMON_STRUCT_LENGTH
 	jp CopyBytes
 
-Predef_SendPkmnIntoBox: ; de6e
+SendPkmnIntoBox: ; de6e
 ; Sends the Pkmn into one of Bills Boxes
 ; the data comes mainly from 'EnemyMon:'
 	ld a, BANK(sBoxCount)
@@ -1010,7 +1010,7 @@
 	cp UNOWN
 	jr nz, .not_unown
 	ld hl, sBoxMon1DVs
-	predef Predef_GetUnownLetter
+	predef GetUnownLetter
 	callfar UpdateUnownDex
 
 .not_unown
@@ -1086,7 +1086,7 @@
 	ret
 ; df8c
 
-Predef_GiveEgg:: ; df8c
+GiveEgg:: ; df8c
 	ld a, [CurPartySpecies]
 	push af
 	callfar GetPreEvolution
@@ -1094,7 +1094,7 @@
 	ld a, [CurPartySpecies]
 	dec a
 
 ; Predef_TryAddMonToParty sets Seen and Caught flags
 ; when it is successful.  This routine will make
 ; sure that we aren't newly setting flags.
 	push af
@@ -1104,11 +1104,11 @@
 	call CheckSeenMon
 	push bc
 
-	call Predef_TryAddMonToParty
+	call TryAddMonToParty
 
 ; If we haven't caught this Pokemon before receiving
 ; the Egg, reset the flag that was just set by
-; Predef_TryAddMonToParty.
+; TryAddMonToParty.
 	pop bc
 	ld a, c
 	and a
@@ -1119,12 +1119,12 @@
 	ld d, $0
 	ld hl, PokedexCaught
 	ld b, RESET_FLAG
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 
 .skip_caught_flag
 ; If we haven't seen this Pokemon before receiving
 ; the Egg, reset the flag that was just set by
-; Predef_TryAddMonToParty.
+; TryAddMonToParty.
 	pop bc
 	ld a, c
 	and a
@@ -1135,7 +1135,7 @@
 	ld d, $0
 	ld hl, PokedexSeen
 	ld b, RESET_FLAG
-	predef Predef_SmallFarFlagAction
+	predef SmallFarFlagAction
 
 .skip_seen_flag
 	pop af
@@ -1360,7 +1360,7 @@
 	ld a, MON_STAT_EXP - 1
 	call GetPartyParamLocation
 	ld b, $1
-	call Predef_CalcPkmnStats
+	call CalcPkmnStats
 	pop de
 	ld a, MON_HP
 	call GetPartyParamLocation
@@ -1372,7 +1372,7 @@
 	ret
 ; e167
 
-Predef_CalcPkmnStats: ; e167
+CalcPkmnStats: ; e167
 ; Calculates all 6 Stats of a Pkmn
 ; b: Take into account stat EXP if TRUE
 ; 'c' counts from 1-6 and points with 'BaseStats' to the base value
@@ -1382,7 +1382,7 @@
 	ld c, $0
 .loop
 	inc c
-	call Predef_CalcPkmnStatC
+	call CalcPkmnStatC
 	ld a, [hMultiplicand + 1]
 	ld [de], a
 	inc de
@@ -1395,7 +1395,7 @@
 	ret
 ; e17b
 
-Predef_CalcPkmnStatC: ; e17b
+CalcPkmnStatC: ; e17b
 ; 'c' is 1-6 and points to the BaseStat
 ; 1: HP
 ; 2: Attack
@@ -1596,7 +1596,7 @@
 	push bc
 	xor a ; PARTYMON
 	ld [MonType], a
-	call Predef_TryAddMonToParty
+	call TryAddMonToParty
 	jr nc, .failed
 	ld hl, PartyMonNicknames
 	ld a, [PartyCount]
@@ -1626,7 +1626,7 @@
 	ld a, [CurPartySpecies]
 	ld [TempEnemyMonSpecies], a
 	callfar LoadEnemyMon
-	call Predef_SendPkmnIntoBox
+	call SendPkmnIntoBox
 	jp nc, .FailedToGiveMon
 	ld a, BOXMON
 	ld [MonType], a
@@ -1094,7 +1094,7 @@
 	dec a
 
-; Predef_TryAddMonToParty sets Seen and Caught flags
+; TryAddMonToParty sets Seen and Caught flags
 ; when it is successful.  This routine will make
 ; sure that we aren't newly setting flags.